"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _apiFetch = _interopRequireDefault(require("@wordpress/api-fetch"));
var _components = require("@wordpress/components");
var _element = require("@wordpress/element");
var _url = require("@wordpress/url");
var _ = require("../");
require("./style.scss");
var _debounce = _interopRequireDefault(require("lodash/debounce"));
var _find = _interopRequireDefault(require("lodash/find"));
var _filter = _interopRequireDefault(require("lodash/filter"));
var _classnames = _interopRequireDefault(require("classnames"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * Category Autocomplete
 */

/**
 * WordPress dependencies.
 */

/**
 * Internal dependencies.
 */

/**
 * External dependencies
 */

/**
 * Category autocomplete field component.
 */class CategoryAutocomplete extends _element.Component {
  /**
   * Class constructor.
   */
  constructor(props) {
    super(props);
    (0, _defineProperty2.default)(this, "state", {
      suggestions: {},
      allCategories: {},
      isLoading: false
    });
    /**
     * Prepare categories data for the API endpoint, call the change handler.
     *
     * @param {Array} tokens An array of category tokens.
     */
    (0, _defineProperty2.default)(this, "handleOnChange", tokens => {
      const {
        onChange
      } = this.props;
      const {
        suggestions
      } = this.state;
      // Categories that are already will be objects, while new additions will be strings (the name).
      // allValues nomalizes the array so that they are all objects.
      const allValues = tokens.filter(token => 'undefined' !== typeof token) // Ensure each token is a valid value.
      .map(token => 'string' === typeof token ? suggestions[token] : token).filter(Boolean);
      onChange(allValues);
    });
    (0, _defineProperty2.default)(this, "getAvailableSuggestions", () => {
      const {
        value
      } = this.props;
      const {
        suggestions
      } = this.state;
      const selectedIds = value.reduce((acc, item) => {
        if (item?.id) {
          acc.push(item.id);
        }
        return acc;
      }, []);
      const availableSuggestions = (0, _filter.default)(suggestions, _ref => {
        let {
          id
        } = _ref;
        return selectedIds.indexOf(id) === -1;
      });
      return availableSuggestions.map(v => v.name);
    });
    this.debouncedUpdateSuggestions = (0, _debounce.default)(this.updateSuggestions, 100);
  }
  componentDidMount() {
    this.setState({
      isLoading: true
    });
    (0, _apiFetch.default)({
      path: (0, _url.addQueryArgs)(`/wp/v2/${this.props.taxonomy}`, {
        per_page: -1,
        _fields: 'id,name'
      })
    }).then(categories => this.setState({
      allCategories: categories
    })).finally(() => this.setState({
      isLoading: false
    }));
  }

  /**
   * Clean up debounced suggestions method.
   */
  componentWillUnmount() {
    this.debouncedUpdateSuggestions.cancel();
  }

  /**
   * Refresh the autocomplete UI based on text that was typed.
   *
   * @param {string} search The typed text to search for.
   */
  updateSuggestions(search) {
    this.setState({
      isLoading: true
    });
    (0, _apiFetch.default)({
      path: (0, _url.addQueryArgs)(`/wp/v2/${this.props.taxonomy}`, {
        search,
        per_page: 20,
        _fields: 'id,name',
        orderby: 'count',
        order: 'desc'
      })
    }).then(categories => {
      this.setState({
        suggestions: categories.reduce((accumulator, category) => ({
          ...accumulator,
          [category.name]: category
        }), {})
      });
    }).finally(() => this.setState({
      isLoading: false
    }));
  }
  /**
   * Render the component.
   */
  render() {
    const {
      className,
      disabled,
      description,
      hideHelpFromVision,
      hideLabelFromVision,
      label,
      value
    } = this.props;
    const {
      allCategories,
      isLoading
    } = this.state;
    const classes = (0, _classnames.default)('newspack-category-autocomplete', className);
    return (0, _jsxRuntime.jsxs)("div", {
      className: classes,
      children: [(0, _jsxRuntime.jsx)(_.FormTokenField, {
        onInputChange: input => this.debouncedUpdateSuggestions(input),
        value: value.reduce((acc, item) => {
          const categoryOrItem = typeof item === 'number' ? (0, _find.default)(allCategories, ['id', item]) : item;
          if (categoryOrItem) {
            acc.push({
              id: categoryOrItem.term_id || categoryOrItem.id,
              value: categoryOrItem.value || categoryOrItem.name
            });
          }
          return acc;
        }, []),
        suggestions: this.getAvailableSuggestions(),
        onChange: this.handleOnChange,
        label: label,
        disabled: disabled,
        description: description,
        hideHelpFromVision: hideHelpFromVision,
        hideLabelFromVision: hideLabelFromVision
      }), isLoading ? (0, _jsxRuntime.jsx)("span", {
        className: "newspack-category-autocomplete__suggestions-spinner",
        children: (0, _jsxRuntime.jsx)(_components.Spinner, {})
      }) : null]
    });
  }
}
CategoryAutocomplete.defaultProps = {
  taxonomy: 'categories'
};
var _default = CategoryAutocomplete;
exports.default = _default;