"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = _interopRequireDefault(require("react"));
var _react2 = require("@testing-library/react");
var _useObjectState = _interopRequireDefault(require("./useObjectState"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
const INIT_STATE = {
  name: 'Foo',
  widgets: [1],
  attributes: {
    bar: 0,
    baz: 1
  }
};
const TestComponent = () => {
  const [state, updateState] = (0, _useObjectState.default)(INIT_STATE);
  return (0, _jsxRuntime.jsxs)("div", {
    children: [(0, _jsxRuntime.jsx)("input", {
      placeholder: "state",
      onChange: () => {},
      value: JSON.stringify(state)
    }), (0, _jsxRuntime.jsx)("button", {
      onClick: () => updateState({
        widgets: []
      }),
      children: "Remove widgets"
    }), (0, _jsxRuntime.jsx)("button", {
      onClick: () => updateState({
        widgets: [1]
      }),
      children: "Add widget"
    }), (0, _jsxRuntime.jsx)("button", {
      onClick: () => updateState({
        attributes: {
          bar: 2
        }
      }),
      children: "Nested update"
    }), (0, _jsxRuntime.jsx)("input", {
      type: "text",
      value: state.name,
      onChange: e => updateState({
        name: e.target.value
      }),
      placeholder: "name"
    })]
  });
};
describe('useObjectState', () => {
  const getState = () => JSON.parse(_react2.screen.getByPlaceholderText('state').getAttribute('value'));
  beforeEach(() => {
    (0, _react2.render)((0, _jsxRuntime.jsx)(TestComponent, {}));
  });
  it('updates arrays', () => {
    expect(getState()).toStrictEqual(INIT_STATE);
    _react2.screen.getByText('Remove widgets').click();
    expect(getState()).toMatchObject({
      widgets: []
    });
    _react2.screen.getByText('Add widget').click();
    expect(getState()).toMatchObject({
      widgets: [1]
    });
  });
  it('updates a simple value', () => {
    _react2.fireEvent.change(_react2.screen.getByPlaceholderText('name'), {
      target: {
        value: 'Ramon'
      }
    });
    expect(getState()).toMatchObject({
      name: 'Ramon'
    });
  });
  it('updates a nested object', () => {
    _react2.screen.getByText('Nested update').click();
    expect(getState()).toMatchObject({
      attributes: {
        bar: 2,
        baz: 1
      }
    });
  });
});