"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _apiFetch = _interopRequireDefault(require("@wordpress/api-fetch"));
var _element = require("@wordpress/element");
var _i18n = require("@wordpress/i18n");
var _icons = require("@wordpress/icons");
var _ = require("../");
require("./style.scss");
var _classnames = _interopRequireDefault(require("classnames"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * Plugin Installer
 */
/**
 * WordPress dependencies.
 */
const __ = _i18n.__;
/**
 * Internal dependencies.
 */
const PLUGIN_STATE_NONE = 0;
const PLUGIN_STATE_ACTIVE = 1;
const PLUGIN_STATE_INSTALLING = 2;
const PLUGIN_STATE_ERROR = 3;

/**
 * External dependencies.
 */

/**
 * Plugin installer.
 */
class PluginInstaller extends _element.Component {
  constructor() {
    var _this;
    super(...arguments);
    _this = this;
    (0, _defineProperty2.default)(this, "componentDidMount", () => {
      const {
        plugins
      } = this.props;
      this.retrievePluginInfo(plugins).then(() => {
        if (this.props.autoInstall) {
          this.installAllPlugins();
        }
      });
    });
    (0, _defineProperty2.default)(this, "componentDidUpdate", prevProps => {
      const {
        autoInstall,
        plugins
      } = this.props;
      const {
        installationInitialized
      } = this.state;
      if (plugins !== prevProps.plugins) {
        this.retrievePluginInfo(plugins);
      }
      if (autoInstall && !installationInitialized) {
        this.installAllPlugins();
      }
    });
    (0, _defineProperty2.default)(this, "retrievePluginInfo", plugins => {
      return new Promise(resolve => {
        (0, _apiFetch.default)({
          path: '/newspack/v1/plugins/'
        }).then(response => {
          const pluginInfo = Object.keys(response).reduce((result, slug) => {
            if (plugins.indexOf(slug) === -1) {
              return result;
            }
            result[slug] = {
              ...response[slug],
              installationStatus: response[slug].Status === 'active' ? PLUGIN_STATE_ACTIVE : PLUGIN_STATE_NONE
            };
            return result;
          }, {});
          this.updatePluginInfo(pluginInfo).then(() => resolve());
        });
      });
    });
    (0, _defineProperty2.default)(this, "installAllPlugins", () => {
      const {
        pluginInfo
      } = this.state;
      this.setState({
        installationInitialized: true
      });
      const promises = Object.keys(pluginInfo).filter(slug => 'active' !== pluginInfo[slug].Status).map(slug => () => this.installPlugin(slug));
      promises.reduce((promise, action) => promise.then(result => action().then(Array.prototype.concat.bind(result))), Promise.resolve([]));
    });
    (0, _defineProperty2.default)(this, "installPlugin", slug => {
      this.setInstallationStatus(slug, PLUGIN_STATE_INSTALLING);
      const params = {
        path: `/newspack/v1/plugins/${slug}/configure/`,
        method: 'post'
      };
      return (0, _apiFetch.default)(params).then(response => {
        const {
          pluginInfo
        } = this.state;
        this.props.onInstalled(slug);
        this.updatePluginInfo({
          ...pluginInfo,
          [slug]: {
            ...response,
            installationStatus: PLUGIN_STATE_ACTIVE
          }
        });
      }).catch(error => {
        this.setInstallationStatus(slug, PLUGIN_STATE_ERROR, error.message);
      });
    });
    (0, _defineProperty2.default)(this, "setChecked", (slug, checked) => {
      const {
        pluginInfo
      } = this.state;
      this.updatePluginInfo({
        ...pluginInfo,
        [slug]: {
          ...pluginInfo[slug],
          checked
        }
      });
    });
    (0, _defineProperty2.default)(this, "setInstallationStatus", function (slug, installationStatus) {
      let notification = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
      const {
        pluginInfo
      } = _this.state;
      _this.updatePluginInfo({
        ...pluginInfo,
        [slug]: {
          ...pluginInfo[slug],
          installationStatus,
          notification
        }
      });
    });
    (0, _defineProperty2.default)(this, "updatePluginInfo", pluginInfo => {
      return new Promise(resolve => {
        const {
          onStatus
        } = this.props;
        this.setState({
          pluginInfo
        }, () => {
          const complete = Object.values(pluginInfo).every(plugin => {
            return 'active' === plugin.Status;
          });
          onStatus({
            complete,
            pluginInfo
          });
          resolve();
        });
      });
    });
    (0, _defineProperty2.default)(this, "classForInstallationStatus", status => {
      switch (status) {
        case PLUGIN_STATE_ACTIVE:
          return 'newspack-plugin-installer__status-active';
        case PLUGIN_STATE_INSTALLING:
          return 'newspack-plugin-installer__status-installing';
        case PLUGIN_STATE_ERROR:
          return 'newspack-plugin-installer__status-error';
        default:
          return 'newspack-plugin-installer__status-none';
      }
    });
    this.state = {
      pluginInfo: {},
      installationInitialized: false
    };
  }
  /**
   * Render.
   */
  render() {
    const {
      autoInstall,
      isSmall,
      withoutFooterButton
    } = this.props;
    const {
      pluginInfo
    } = this.state;
    const {
      is_atomic: isAtomic
    } = window;
    const slugs = Object.keys(pluginInfo);

    // Store all plugin status info for installer button text value based on current status.
    const currentPluginStatuses = [];
    slugs.forEach(slug => {
      const plugin = pluginInfo[slug];
      currentPluginStatuses.push(plugin.Status);
    });

    // Make sure plugin status falls in either one of these, to handle button text.
    const pluginInstalled = currentStatus => currentStatus === 'active' || currentStatus === 'inactive';
    const buttonText = currentPluginStatuses.every(pluginInstalled) ? __('Activate', 'newspack') : __('Install', 'newspack');
    const needsInstall = slugs.some(slug => {
      const plugin = pluginInfo[slug];
      return plugin.Status !== 'active' && plugin.installationStatus === PLUGIN_STATE_NONE;
    });
    return (0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [(!pluginInfo || !Object.keys(pluginInfo).length) && (0, _jsxRuntime.jsxs)("div", {
        className: "newspack-plugin-installer_is-waiting",
        children: [(0, _jsxRuntime.jsx)(_.Waiting, {
          isLeft: true
        }), __('Retrieving plugin information…')]
      }), pluginInfo && slugs.length > 0 && slugs.map(slug => {
        const plugin = pluginInfo[slug];
        const {
          Name,
          Description,
          Download,
          Status,
          installationStatus,
          notification
        } = plugin;
        const isWaiting = installationStatus === PLUGIN_STATE_INSTALLING;
        const isButton = !isWaiting && Status !== 'active';
        const installable = Download || pluginInstalled(Status);
        let actionText;
        if (installationStatus === PLUGIN_STATE_INSTALLING) {
          actionText = 'inactive' === Status ? __('Activating…') : __('Installing…');
        } else if (!installable) {
          actionText = (0, _jsxRuntime.jsxs)("span", {
            className: "newspack-plugin-installer__status",
            children: [isAtomic ? __('Contact Newspack support to install', 'newspack') : __('Plugin must be installed manually', 'newspack'), (0, _jsxRuntime.jsx)("span", {
              className: "newspack-checkbox-icon"
            })]
          });
        } else if (Status === 'uninstalled') {
          actionText = (0, _jsxRuntime.jsxs)("span", {
            className: "newspack-plugin-installer__status",
            children: [__('Install', 'newspack'), (0, _jsxRuntime.jsx)("span", {
              className: "newspack-checkbox-icon"
            })]
          });
        } else if (Status === 'inactive') {
          actionText = (0, _jsxRuntime.jsxs)("span", {
            className: "newspack-plugin-installer__status",
            children: [__('Activate', 'newspack'), (0, _jsxRuntime.jsx)("span", {
              className: "newspack-checkbox-icon"
            })]
          });
        } else if (Status === 'active') {
          actionText = (0, _jsxRuntime.jsxs)("span", {
            className: "newspack-plugin-installer__status",
            children: [__('Installed', 'newspack'), (0, _jsxRuntime.jsx)("span", {
              className: "newspack-checkbox-icon newspack-checkbox-icon--checked",
              children: (0, _jsxRuntime.jsx)(_icons.Icon, {
                icon: _icons.check
              })
            })]
          });
        }
        const classes = (0, _classnames.default)('newspack-action-card__plugin-installer', this.classForInstallationStatus(installationStatus));
        const onClick = isButton ? () => this.installPlugin(slug) : null;
        return (0, _jsxRuntime.jsx)(_.ActionCard, {
          title: Name,
          description: Description,
          disabled: !installable,
          actionText: actionText,
          isSmall: isSmall,
          isWaiting: isWaiting,
          onClick: onClick,
          notification: notification,
          notificationLevel: "error",
          notificationHTML: true,
          className: classes
        }, slug);
      }), !withoutFooterButton && !autoInstall && pluginInfo && slugs.length > 0 && (0, _jsxRuntime.jsx)("div", {
        className: "newspack-buttons-card",
        children: (0, _jsxRuntime.jsx)(_.Button, {
          disabled: !needsInstall,
          isPrimary: true,
          onClick: this.installAllPlugins,
          children: buttonText
        })
      })]
    });
  }
}
PluginInstaller.defaultProps = {
  onStatus: () => {},
  onInstalled: () => {}
};
var _default = PluginInstaller;
exports.default = _default;