"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _element = require("@wordpress/element");
var _hooks = require("@wordpress/hooks");
var _i18n = require("@wordpress/i18n");
var _components = require("@wordpress/components");
var _ = require("../");
require("./style.scss");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * Ads Settings Section.
 */
/**
 * WordPress dependencies
 */
const __ = _i18n.__;
/**
 * Internal dependencies
 */
const isSelectControl = setting => {
  return Array.isArray(setting.options) && setting.options.length;
};
const getControlComponent = setting => {
  if (isSelectControl(setting)) {
    return _.SelectControl;
  }
  switch (setting.type) {
    case 'checkbox':
    case 'boolean':
      return _components.CheckboxControl;
    default:
      return _.TextControl;
  }
};
const getControlType = setting => {
  switch (setting.type) {
    case 'int':
    case 'integer':
    case 'float':
    case 'number':
      return 'number';
    case 'string':
    case 'text':
      return 'text';
    case 'password':
      return 'password';
    case 'boolean':
    case 'checkbox':
      return 'checkbox';
    default:
      return null;
  }
};
const SettingsSection = props => {
  const [saveDisabled, setSaveDisabled] = (0, _element.useState)(true);
  const {
    error,
    sectionKey,
    active,
    title,
    description,
    fields,
    disabled,
    onChange,
    onUpdate
  } = props;
  const getControlProps = setting => ({
    disabled,
    name: `${setting.section}_${setting.key}`,
    type: getControlType(setting),
    label: setting.description,
    help: setting.help || null,
    options: setting.options?.map(option => ({
      value: option.value,
      label: option.name || option.label
    })) || null,
    value: setting.value,
    multiple: isSelectControl(setting) && setting.multiple ? true : null,
    checked: setting.type === 'boolean' ? !!setting.value : null,
    onChange: value => {
      onChange(setting.key, value);
      setSaveDisabled(false);
    }
  });
  const createFilter = function (name) {
    let defaultComponent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
    return (0, _hooks.applyFilters)(`newspack.settingSection.${sectionKey}.${name}`, defaultComponent, props);
  };
  let columns = 2;
  if (fields.length % 3 === 0) {
    columns = 3;
  } else if (fields.length === 1) {
    columns = 1;
  }
  return (0, _jsxRuntime.jsx)(_.ActionCard, {
    isMedium: true,
    disabled: disabled,
    title: title,
    description: description,
    toggleChecked: active,
    hasGreyHeader: active || null === active,
    toggleOnChange: active !== null ? value => onUpdate({
      active: value
    }) : null,
    actionContent: (active || null === active) && createFilter('buttons', (0, _jsxRuntime.jsx)(_.Button, {
      variant: "primary",
      disabled: disabled || saveDisabled,
      onClick: () => {
        onUpdate();
        setSaveDisabled(true);
      },
      children: __('Save Settings', 'newspack')
    })),
    children: (active || active === null) && (0, _jsxRuntime.jsxs)(_element.Fragment, {
      children: [error?.message && (0, _jsxRuntime.jsx)(_.Notice, {
        noticeText: error.message,
        isError: true
      }), createFilter('beforeControls'), (0, _jsxRuntime.jsx)(_.Grid, {
        columns: columns,
        gutter: 32,
        children: fields.map(setting => {
          const Control = getControlComponent(setting); // eslint-disable-line @wordpress/no-unused-vars-before-return, no-unused-vars
          return (0, _hooks.applyFilters)(`newspack.settingsSection.${sectionKey}.control`, (0, _jsxRuntime.jsx)(Control, {
            ...getControlProps(setting)
          }, setting.key), {
            sectionKey,
            setting,
            onChange
          });
        })
      })]
    })
  });
};
var _default = SettingsSection;
exports.default = _default;