"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _classnames = _interopRequireDefault(require("classnames"));
var _apiFetch = _interopRequireDefault(require("@wordpress/api-fetch"));
var _element = require("@wordpress/element");
var _i18n = require("@wordpress/i18n");
var _ = require("../");
var _SettingsSection = _interopRequireDefault(require("./SettingsSection"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * External dependencies
 */
/**
 * WordPress dependencies.
 */
/**
 * Internal dependencies.
 */
const __ = _i18n.__;
class PluginSettings extends _element.Component {
  constructor() {
    super(...arguments);
    (0, _defineProperty2.default)(this, "fetchSettings", () => {
      const {
        afterFetch,
        pluginSlug,
        isWizard
      } = this.props;
      this.setState({
        inFlight: true
      });
      (0, _apiFetch.default)({
        path: isWizard ? `/newspack/v1/wizard/${pluginSlug}/settings` : `/${pluginSlug}/v1/settings`
      }).then(settings => {
        this.setState({
          settings,
          error: null
        });
        if ('function' === typeof afterFetch) {
          afterFetch(settings);
        }
      }).catch(error => {
        this.setState({
          error
        });
      }).finally(() => {
        this.setState({
          inFlight: false
        });
      });
    });
    (0, _defineProperty2.default)(this, "getSettingsValues", sectionKey => {
      return this.state.settings[sectionKey]?.reduce((map, setting) => {
        map[setting.key] = setting.value;
        return map;
      }, {}) || {};
    });
    (0, _defineProperty2.default)(this, "handleSettingChange", sectionKey => (key, value) => {
      const sectionSettings = [...this.state.settings[sectionKey]];
      sectionSettings.forEach(setting => {
        if (setting.key === key) {
          setting.value = value;
        }
      });
      this.setState({
        settings: {
          ...this.state.settings,
          [sectionKey]: sectionSettings
        }
      });
    });
    (0, _defineProperty2.default)(this, "handleSectionUpdate", sectionKey => data => {
      const {
        afterUpdate,
        pluginSlug,
        isWizard
      } = this.props;
      this.setState({
        inFlight: true
      });
      (0, _apiFetch.default)({
        path: isWizard ? `/newspack/v1/wizard/${pluginSlug}/settings` : `/${pluginSlug}/v1/settings`,
        method: 'POST',
        data: {
          section: sectionKey,
          settings: data ? data : this.getSettingsValues(sectionKey)
        }
      }).then(settings => {
        this.setState({
          settings: {
            ...this.state.settings,
            [sectionKey]: settings[sectionKey]
          },
          error: null
        });
        if ('function' === typeof afterUpdate) {
          afterUpdate(settings);
        }
      }).catch(error => {
        this.setState({
          error
        });
      }).finally(() => {
        this.setState({
          inFlight: false
        });
      });
    });
    /**
     * Get the section setting containing section information.
     *
     * @param {string} sectionKey The section name.
     * @return {Object} The section setting.
     */
    (0, _defineProperty2.default)(this, "getSectionInfo", sectionKey => {
      return this.state.settings[sectionKey]?.find(setting => !setting.key || setting.key === 'active');
    });
    /**
     * Get the section title.
     *
     * @param {string} sectionKey The section name.
     * @return {string} The section title.
     */
    (0, _defineProperty2.default)(this, "getSectionTitle", sectionKey => {
      return this.getSectionInfo(sectionKey)?.description;
    });
    /**
     * Get the section description.
     *
     * @param {string} sectionKey The section name.
     * @return {string} The section description.
     */
    (0, _defineProperty2.default)(this, "getSectionDescription", sectionKey => {
      return this.getSectionInfo(sectionKey)?.help;
    });
    /**
     * Get whether a section is active.
     *
     * @param {string} sectionKey The section name.
     * @return {?boolean} Whether the section is active or not. Null if the section is not found or does not support activation.
     */
    (0, _defineProperty2.default)(this, "isSectionActive", sectionKey => {
      const {
        settings
      } = this.state;
      const activation = settings[sectionKey]?.find(setting => setting.key === 'active');
      if (!activation) {
        return null;
      }
      return activation.value;
    });
    /**
     * Get list of section field settings.
     *
     * @param {string} sectionKey The section name.
     * @return {?Array} List of section fields.
     */
    (0, _defineProperty2.default)(this, "getSectionFields", sectionKey => {
      return this.state.settings[sectionKey]?.filter(setting => setting.key && setting.key !== 'active');
    });
    this.state = {
      inFlight: false,
      settings: {},
      error: null
    };
  }
  componentDidMount() {
    this.fetchSettings();
  }
  /**
   * Render.
   */
  render() {
    const {
      title,
      description,
      hasGreyHeader,
      children
    } = this.props;
    const {
      settings,
      inFlight,
      error
    } = this.state;
    return (0, _jsxRuntime.jsxs)(_element.Fragment, {
      children: [title && (0, _jsxRuntime.jsx)(_.SectionHeader, {
        title: title,
        description: description
      }), error && (0, _jsxRuntime.jsx)(_.Notice, {
        isError: true,
        noticeText: error.message
      }), (0, _jsxRuntime.jsxs)("div", {
        className: (0, _classnames.default)('newspack-plugin-settings', {
          'newspack-wizard-section__is-loading': inFlight && !Object.keys(settings).length
        }),
        children: [Object.keys(settings).map(sectionKey => (0, _jsxRuntime.jsx)(_SettingsSection.default, {
          disabled: inFlight,
          sectionKey: sectionKey,
          title: this.getSectionTitle(sectionKey),
          description: this.getSectionDescription(sectionKey),
          active: this.isSectionActive(sectionKey),
          fields: this.getSectionFields(sectionKey),
          onChange: this.handleSettingChange(sectionKey),
          onUpdate: this.handleSectionUpdate(sectionKey),
          hasGreyHeader: hasGreyHeader
        }, sectionKey)), children]
      })]
    });
  }
}
PluginSettings.defaultProps = {
  title: __('General Settings', 'newspack')
};
PluginSettings.Section = _SettingsSection.default;
var _default = PluginSettings;
exports.default = _default;