"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = PositionControl;
var _i18n = require("@wordpress/i18n");
var _components = require("@wordpress/components");
var _classnames = _interopRequireDefault(require("classnames"));
require("./style.scss");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * WordPress dependencies
 */
const __ = _i18n.__;
/**
 * External dependencies
 */
/**
 * Internal dependencies
 */
function PositionControl(_ref) {
  let {
    allowedPositions,
    value,
    label,
    help,
    onChange,
    size,
    ...props
  } = _ref;
  /**
   * Set layout options
   */
  const options = size === 'full-width' ? [{
    value: 'top',
    /* translators: Overlay Position */
    label: __('Top', 'newspack')
  }, {
    value: 'center',
    /* translators: Overlay Position */
    label: __('Center', 'newspack')
  }, {
    value: 'bottom',
    /* translators: Overlay Position */
    label: __('Bottom', 'newspack')
  }] : [{
    value: 'top_left',
    /* translators: Overlay Position */
    label: __('Top Left', 'newspack')
  }, {
    value: 'top',
    /* translators: Overlay Position */
    label: __('Top Center', 'newspack')
  }, {
    value: 'top_right',
    /* translators: Overlay Position */
    label: __('Top Right', 'newspack')
  }, {
    value: 'center_left',
    /* translators: Overlay Position */
    label: __('Center Left', 'newspack')
  }, {
    value: 'center',
    /* translators: Overlay Position */
    label: __('Center', 'newspack')
  }, {
    value: 'center_right',
    /* translators: Overlay Position */
    label: __('Center Right', 'newspack')
  }, {
    value: 'bottom_left',
    /* translators: Overlay Position */
    label: __('Bottom Left', 'newspack')
  }, {
    value: 'bottom',
    /* translators: Overlay Position */
    label: __('Bottom Center', 'newspack')
  }, {
    value: 'bottom_right',
    /* translators: Overlay Position */
    label: __('Bottom Right', 'newspack')
  }];
  return (0, _jsxRuntime.jsxs)("div", {
    className: (0, _classnames.default)('newspack-position-placement-control', 'size-' + size),
    children: [(0, _jsxRuntime.jsx)("p", {
      className: "components-base-control__label",
      children: label
    }), (0, _jsxRuntime.jsx)(_components.ButtonGroup, {
      "aria-label": __('Select Position', 'newspack'),
      ...props,
      children: options.map((option, index) => {
        return (0, _jsxRuntime.jsx)("div", {
          className: option.value === value ? 'is-selected' : null,
          children: (0, _jsxRuntime.jsx)(_components.Button, {
            isSmall: true,
            title: option.label,
            "aria-label": option.label,
            isPrimary: option.value === value,
            onClick: () => {
              onChange(option.value);
            },
            disabled: allowedPositions?.length && !allowedPositions.includes(option.value)
          })
        }, `newspack-position-placement-item-${index}`);
      })
    }), (0, _jsxRuntime.jsx)("p", {
      className: "components-base-control__help",
      children: help
    })]
  });
}