"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = _interopRequireDefault(require("react"));
var _react2 = require("@testing-library/react");
var _ = _interopRequireDefault(require("./"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react3 = require("@emotion/react");
describe('ProgressBar', () => {
  it('should render a progress indicator', () => {
    const {
      getByTestId
    } = (0, _react2.render)((0, _jsxRuntime.jsx)(_.default, {
      completed: "1",
      total: "2"
    }));
    const indicator = getByTestId('progress-bar-indicator');
    expect(indicator).toHaveAttribute('style', 'width: 50%;');
  });
  it('should render a label', () => {
    const label = 'test label';
    const {
      getByText
    } = (0, _react2.render)((0, _jsxRuntime.jsx)(_.default, {
      completed: "1",
      total: "2",
      label: label
    }));
    expect(getByText(label)).toBeInTheDocument();
  });
  it('should render progress as a fraction', () => {
    const {
      getByText
    } = (0, _react2.render)((0, _jsxRuntime.jsx)(_.default, {
      completed: "1",
      total: "2",
      displayFraction: true
    }));
    expect(getByText('1/2')).toBeInTheDocument();
  });
  it('should render with both label and fraction', () => {
    const label = 'test label';
    const {
      getByText
    } = (0, _react2.render)((0, _jsxRuntime.jsx)(_.default, {
      completed: "1",
      total: "2",
      label: label,
      displayFraction: true
    }));
    expect(getByText(label)).toBeInTheDocument();
    expect(getByText('1/2')).toBeInTheDocument();
  });
  describe('should calculate progress correctly', () => {
    [{
      props: {
        completed: 1,
        total: 2
      },
      expectedWidth: 50
    }, {
      props: {
        completed: 2,
        total: 3
      },
      expectedWidth: 67
    }, {
      props: {
        completed: 6,
        total: 3
      },
      expectedWidth: 100
    }].forEach(_ref => {
      let {
        props,
        expectedWidth
      } = _ref;
      it(`with expected  progress of ${expectedWidth}`, () => {
        const {
          getByTestId
        } = (0, _react2.render)((0, _react3.createElement)(_.default, {
          ...props,
          key: expectedWidth
        }));
        expect(getByTestId('progress-bar-indicator')).toHaveAttribute('style', `width: ${expectedWidth}%;`);
      });
    });
  });
  it('should handle non-numeric values in ProgressBar element', () => {
    const {
      getByText,
      getByTestId
    } = (0, _react2.render)((0, _jsxRuntime.jsx)(_.default, {
      completed: "cats",
      total: "dogs",
      displayFraction: true
    }));
    expect(getByText('0/0')).toBeInTheDocument();
    expect(getByTestId('progress-bar-indicator')).toHaveAttribute('style', 'width: 100%;');
  });
  it('should handle non-logical values in ProgressBar element', () => {
    const {
      getByText,
      getByTestId
    } = (0, _react2.render)((0, _jsxRuntime.jsx)(_.default, {
      completed: "3",
      total: "-1",
      displayFraction: true
    }));
    expect(getByText('0/0')).toBeInTheDocument();
    expect(getByTestId('progress-bar-indicator')).toHaveAttribute('style', 'width: 100%;');
  });
});