"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _element = require("@wordpress/element");
var _i18n = require("@wordpress/i18n");
var _icons = require("@wordpress/icons");
var _components = require("@wordpress/components");
var _ = require("../");
require("./style.scss");
var _classnames = _interopRequireDefault(require("classnames"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * WordPress dependencies.
 */
const __ = _i18n.__;
/**
 * Internal dependencies.
 */
/**
 * External dependencies.
 */
const PORTAL_PARENT_ID = 'newspack-components-web-preview-wrapper';

/**
 * Web Preview. A component to preview a website in an iframe, with device sizing options.
 */
class WebPreview extends _element.Component {
  constructor(props) {
    super(props);
    (0, _defineProperty2.default)(this, "state", {
      device: 'desktop',
      loaded: false,
      isPreviewVisible: false
    });
    /**
     * Create JSX for the modal
     */
    (0, _defineProperty2.default)(this, "getWebPreviewModal", () => {
      const {
        beforeLoad = () => {},
        onClose = () => {},
        url
      } = this.props;
      const {
        device,
        loaded,
        isPreviewVisible
      } = this.state;
      if (!this.modalDOMElement || !isPreviewVisible) {
        return null;
      }
      const classes = (0, _classnames.default)('newspack-web-preview', device, loaded && 'is-loaded');
      beforeLoad();
      return (0, _element.createPortal)((0, _jsxRuntime.jsx)("div", {
        className: classes,
        children: (0, _jsxRuntime.jsxs)("div", {
          className: "newspack-web-preview__interior",
          children: [(0, _jsxRuntime.jsxs)("div", {
            className: "newspack-web-preview__toolbar",
            children: [(0, _jsxRuntime.jsx)("div", {
              className: "newspack-web-preview__toolbar-left",
              children: (0, _jsxRuntime.jsxs)(_components.ButtonGroup, {
                children: [(0, _jsxRuntime.jsx)(_components.Button, {
                  onClick: () => this.setState({
                    device: 'desktop'
                  }),
                  variant: 'desktop' === device && 'primary',
                  icon: _icons.desktop,
                  label: __('Preview Desktop Size', 'newspack')
                }), (0, _jsxRuntime.jsx)(_components.Button, {
                  onClick: () => this.setState({
                    device: 'tablet'
                  }),
                  variant: 'tablet' === device && 'primary',
                  icon: _icons.tablet,
                  label: __('Preview Tablet Size', 'newspack')
                }), (0, _jsxRuntime.jsx)(_components.Button, {
                  onClick: () => this.setState({
                    device: 'phone'
                  }),
                  variant: 'phone' === device && 'primary',
                  icon: _icons.mobile,
                  label: __('Preview Phone Size', 'newspack')
                })]
              })
            }), (0, _jsxRuntime.jsx)("div", {
              className: "newspack-web-preview__toolbar-right",
              children: (0, _jsxRuntime.jsx)(_components.Button, {
                onClick: () => {
                  onClose();
                  this.setState({
                    isPreviewVisible: false,
                    loaded: false
                  });
                },
                icon: _icons.closeSmall,
                label: __('Close Preview', 'newspack')
              })
            })]
          }), (0, _jsxRuntime.jsxs)("div", {
            className: "newspack-web-preview__content",
            children: [!loaded && (0, _jsxRuntime.jsxs)("div", {
              className: "newspack-web-preview__is-waiting",
              children: [(0, _jsxRuntime.jsx)(_.Waiting, {
                isLeft: true
              }), __('Loading…', 'newspack')]
            }), (0, _jsxRuntime.jsx)("iframe", {
              ref: this.iframeRef,
              title: "web-preview",
              src: url,
              onLoad: () => {
                this.setState({
                  loaded: true
                });
                this.props.onLoad(this.iframeRef.current);
              }
            })]
          })]
        })
      }), this.modalDOMElement);
    });
    (0, _defineProperty2.default)(this, "showPreview", () => {
      this.setState({
        isPreviewVisible: true
      });
    });
    this.iframeRef = (0, _element.createRef)();
  }

  /**
   * If a div with id PORTAL_PARENT_ID exists, assign it to class field.
   * If not, create it and append to the body.
   */
  componentDidMount() {
    const existingDOMElement = document.getElementById(PORTAL_PARENT_ID);
    this.modalDOMElement = existingDOMElement || document.createElement('div');
    if (!existingDOMElement) {
      this.modalDOMElement.id = PORTAL_PARENT_ID;
      document.body.appendChild(this.modalDOMElement);
    }
  }

  /**
   * Add or remove applicable body classes
   */
  componentDidUpdate() {
    if (this.state.isPreviewVisible === true) {
      document.body.classList.add('newspack-web-preview--open');
    } else {
      document.body.classList.remove('newspack-web-preview--open');
    }
  }
  /**
   * Render.
   */
  render() {
    const {
      label,
      variant,
      /**
       * Inversion of control - let the caller render
       * the button that will trigger the modal
       */
      renderButton
    } = this.props;
    return (0, _jsxRuntime.jsxs)(_element.Fragment, {
      children: [renderButton ? renderButton({
        showPreview: this.showPreview
      }) : (0, _jsxRuntime.jsx)(_components.Button, {
        variant: variant,
        onClick: this.showPreview,
        tabIndex: "0",
        children: label
      }), this.getWebPreviewModal()]
    });
  }
}
WebPreview.defaultProps = {
  url: '//newspack.com',
  label: __('Preview', 'newspack'),
  onLoad: () => {}
};
var _default = WebPreview;
exports.default = _default;