"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = withWizard;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _element = require("@wordpress/element");
var _i18n = require("@wordpress/i18n");
var _apiFetch = _interopRequireDefault(require("@wordpress/api-fetch"));
var _icons = require("@wordpress/icons");
var _ = require("../");
var _router = _interopRequireDefault(require("../proxied-imports/router"));
var _footer = _interopRequireDefault(require("../footer"));
require("./style.scss");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * WordPress dependencies.
 */
const __ = _i18n.__;
/**
 * Internal dependencies.
 */
const {
  Redirect,
  Route
} = _router.default;

/**
 * Higher-Order Component to provide plugin management and error handling to Newspack Wizards.
 */
function withWizard(WrappedComponent, requiredPlugins) {
  return class WrappedWithWizard extends _element.Component {
    constructor(props) {
      super(props);
      (0, _defineProperty2.default)(this, "componentDidMount", () => {
        // If there are no requiredPlugins, fire onWizardReady as soon as component mounts.
        if (!requiredPlugins) {
          const instance = this.wrappedComponentRef.current;
          // eslint-disable-next-line no-unused-expressions
          instance && instance.onWizardReady && instance.onWizardReady();
        }
      });
      /**
       * Set the error. Called by Wizards when an error occurs.
       *
       * @return {Promise} Resolved after state update
       */
      (0, _defineProperty2.default)(this, "setError", error => {
        return new Promise(resolve => {
          this.setState({
            error: error || null
          }, () => resolve());
        });
      });
      /**
       * Render any errors that need rendering.
       *
       * @return {Component} Error UI
       */
      (0, _defineProperty2.default)(this, "getError", () => {
        const {
          error
        } = this.state;
        if (!error) {
          return null;
        }
        const parsedError = this.parseError(error);
        const {
          level
        } = parsedError;
        if ('fatal' === level) {
          return this.getFatalError(parsedError);
        }
        return this.getErrorNotice(parsedError);
      });
      /**
       * Get a notice-level error.
       *
       * @param {Error} error object already parsed by parseError
       * @return {Component} Error notice
       */
      (0, _defineProperty2.default)(this, "getErrorNotice", error => {
        const {
          message
        } = error;
        return (0, _jsxRuntime.jsx)(_.Notice, {
          isError: true,
          className: "newspack-wizard__above-header",
          noticeText: message,
          rawHTML: true
        });
      });
      /**
       * Get a fatal-level error.
       *
       * @param {Error} error object already parsed by parseError
       * @return {Component} React object
       */
      (0, _defineProperty2.default)(this, "getFatalError", error => {
        const fallbackURL = this.getFallbackURL();
        if (!fallbackURL) {
          return null;
        }
        const {
          message
        } = error;
        return (0, _jsxRuntime.jsxs)(_.Modal, {
          title: __('Unrecoverable error'),
          onRequestClose: () => window.location = fallbackURL,
          children: [(0, _jsxRuntime.jsx)(_.Notice, {
            noticeText: message,
            isError: true,
            rawHTML: true
          }), (0, _jsxRuntime.jsx)(_.Card, {
            buttonsCard: true,
            noBorder: true,
            className: "justify-end",
            children: (0, _jsxRuntime.jsx)(_.Button, {
              isPrimary: true,
              href: fallbackURL,
              children: __('Return to Dashboard', 'newspack')
            })
          })]
        });
      });
      /**
       * Get all the relevant info out of a raw API error response.
       *
       * @param {Object} error error object
       * @return {Object} Error object with relevant fields and defaults
       */
      (0, _defineProperty2.default)(this, "parseError", error => {
        const {
          data,
          message,
          code
        } = error;
        let level = 'fatal';
        if (!!data && 'level' in data) {
          level = data.level;
        } else if ('rest_invalid_param' === code) {
          level = 'notice';
        }
        return {
          message,
          level
        };
      });
      /**
       * Called when plugin installation is complete. Updates state and calls onWizardReady on the wrapped component.
       */
      (0, _defineProperty2.default)(this, "pluginInstallationStatus", _ref => {
        let {
          complete
        } = _ref;
        if (this.state.loading) {
          this.doneLoading();
        }
        const instance = this.wrappedComponentRef.current;
        this.setState({
          complete
        }, () => {
          // eslint-disable-next-line no-unused-expressions
          complete && instance && instance.onWizardReady && instance.onWizardReady();
        });
      });
      /**
       * Begin loading.
       */
      (0, _defineProperty2.default)(this, "startLoading", quiet => {
        if (quiet) {
          this.setState(state => ({
            quietLoading: state.quietLoading + 1
          }));
        } else {
          this.setState(state => ({
            loading: state.loading + 1
          }));
        }
      });
      /**
       * End loading.
       */
      (0, _defineProperty2.default)(this, "doneLoading", quiet => {
        if (quiet) {
          this.setState(state => ({
            quietLoading: state.quietLoading - 1
          }));
        } else {
          this.setState(state => ({
            loading: state.loading - 1
          }));
        }
      });
      /**
       * Replacement for core apiFetch that automatically manages wizard loading UI.
       */
      (0, _defineProperty2.default)(this, "wizardApiFetch", args => {
        const {
          quiet
        } = args;
        this.startLoading(quiet);
        return new Promise((resolve, reject) => {
          (0, _apiFetch.default)(args).then(response => {
            this.doneLoading(quiet);
            resolve(response);
          }).catch(error => {
            this.doneLoading(quiet);
            reject(error);
          });
        });
      });
      /**
       * Render a Route that checks for plugin installation requirements, and redirects to '/' when all are done.
       *
       * @return {void}
       */
      (0, _defineProperty2.default)(this, "pluginRequirements", () => {
        const {
          complete
        } = this.state;
        /* After all plugins are loaded, redirect to / (this could be configurable) */
        if (complete) {
          return (0, _jsxRuntime.jsx)(Redirect, {
            from: "/plugin-requirements",
            to: "/"
          });
        }
        return (0, _jsxRuntime.jsx)(Route, {
          path: "/",
          render: () => (0, _jsxRuntime.jsxs)(_element.Fragment, {
            children: [complete !== null && (0, _jsxRuntime.jsx)("div", {
              className: "newspack-wizard__header",
              children: (0, _jsxRuntime.jsx)("div", {
                className: "newspack-wizard__header__inner",
                children: (0, _jsxRuntime.jsxs)("div", {
                  className: "newspack-wizard__title",
                  children: [(0, _jsxRuntime.jsx)(_.Button, {
                    isLink: true,
                    href: newspack_urls.dashboard,
                    label: __('Return to Dashboard', 'newspack'),
                    showTooltip: true,
                    icon: _icons.home,
                    iconSize: 36,
                    children: (0, _jsxRuntime.jsx)(_.NewspackIcon, {
                      size: 36
                    })
                  }), (0, _jsxRuntime.jsx)("div", {
                    children: (0, _jsxRuntime.jsx)("h2", {
                      children: requiredPlugins.length > 1 ? __('Required plugins', 'newspack') : __('Required plugin', 'newspack')
                    })
                  })]
                })
              })
            }), (0, _jsxRuntime.jsx)("div", {
              className: "newspack-wizard newspack-wizard__content",
              children: (0, _jsxRuntime.jsx)(_.PluginInstaller, {
                plugins: requiredPlugins,
                onStatus: status => this.pluginInstallationStatus(status)
              })
            })]
          })
        });
      });
      (0, _defineProperty2.default)(this, "getFallbackURL", () => {
        if (typeof newspack_urls !== 'undefined') {
          return newspack_urls.dashboard;
        }
      });
      this.state = {
        complete: null,
        error: null,
        loading: requiredPlugins && requiredPlugins.length > 0 ? 1 : 0,
        quietLoading: false
      };
      this.wrappedComponentRef = (0, _element.createRef)();
    }
    /**
     * Render.
     */
    render() {
      const {
        simpleFooter
      } = this.props;
      const {
        loading,
        quietLoading,
        error
      } = this.state;
      const loadingClasses = [loading ? 'newspack-wizard__is-loading' : 'newspack-wizard__is-loaded'];
      if (quietLoading) {
        loadingClasses.push('newspack-wizard__is-loading-quiet');
      }
      return (0, _jsxRuntime.jsxs)(_element.Fragment, {
        children: [this.getError(), (0, _jsxRuntime.jsx)("div", {
          className: loadingClasses.join(' '),
          children: (0, _jsxRuntime.jsx)(WrappedComponent, {
            pluginRequirements: requiredPlugins && this.pluginRequirements(),
            clearError: this.clearError,
            getError: this.getError,
            errorData: error,
            setError: this.setError,
            isLoading: loading,
            startLoading: this.startLoading,
            doneLoading: this.doneLoading,
            wizardApiFetch: this.wizardApiFetch,
            ref: this.wrappedComponentRef,
            ...this.props
          })
        }), !loading && (0, _jsxRuntime.jsx)(_footer.default, {
          simple: simpleFooter
        })]
      });
    }
  };
}