"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _classnames = _interopRequireDefault(require("classnames"));
var _data = require("@wordpress/data");
var _element = require("@wordpress/element");
var _i18n = require("@wordpress/i18n");
var _icons = require("@wordpress/icons");
var _ = require("../");
var _router = _interopRequireDefault(require("../proxied-imports/router"));
var _store = _interopRequireWildcard(require("./store"));
var _utils = require("./store/utils");
var _WizardError = _interopRequireDefault(require("./components/WizardError"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
/**
 * External dependencies.
 */
/**
 * WordPress dependencies.
 */
const __ = _i18n.__;
/**
 * Internal dependencies
 */
(0, _store.default)();
const {
  HashRouter,
  Redirect,
  Route,
  Switch
} = _router.default;
const Wizard = _ref => {
  let {
    sections = [],
    apiSlug,
    headerText,
    subHeaderText,
    hasSimpleFooter,
    className,
    renderAboveSections,
    requiredPlugins = []
  } = _ref;
  const isLoading = (0, _data.useSelect)(select => select(_store.WIZARD_STORE_NAMESPACE).isLoading());
  const isQuietLoading = (0, _data.useSelect)(select => select(_store.WIZARD_STORE_NAMESPACE).isQuietLoading());

  // Trigger initial data fetch. Some sections might not use the wizard data,
  // but for consistency, fetching is triggered regardless of the section.
  (0, _data.useSelect)(select => select(_store.WIZARD_STORE_NAMESPACE).getWizardAPIData(apiSlug));
  let displayedSections = sections.filter(section => !section.isHidden);
  const [pluginRequirementsSatisfied, setPluginRequirementsSatisfied] = (0, _element.useState)(requiredPlugins.length === 0);
  if (!pluginRequirementsSatisfied) {
    headerText = requiredPlugins.length > 1 ? __('Required plugins', 'newspack') : __('Required plugin', 'newspack');
    displayedSections = [{
      path: '/',
      render: () => (0, _jsxRuntime.jsx)(_.PluginInstaller, {
        plugins: requiredPlugins,
        onStatus: _ref2 => {
          let {
            complete
          } = _ref2;
          return setPluginRequirementsSatisfied(complete);
        }
      })
    }];
  }
  return (0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [(0, _jsxRuntime.jsx)("div", {
      className: (0, _classnames.default)(isLoading ? 'newspack-wizard__is-loading' : 'newspack-wizard__is-loaded', {
        'newspack-wizard__is-loading-quiet': isQuietLoading
      }),
      children: (0, _jsxRuntime.jsxs)(HashRouter, {
        hashType: "slash",
        children: [newspack_aux_data.is_debug_mode && (0, _jsxRuntime.jsx)(_.Notice, {
          debugMode: true
        }), (0, _jsxRuntime.jsx)("div", {
          className: "bg-white",
          children: (0, _jsxRuntime.jsx)("div", {
            className: "newspack-wizard__header__inner",
            children: (0, _jsxRuntime.jsxs)("div", {
              className: "newspack-wizard__title",
              children: [(0, _jsxRuntime.jsx)(_.Button, {
                isLink: true,
                href: newspack_urls.dashboard,
                label: __('Return to Dashboard', 'newspack'),
                showTooltip: true,
                icon: _icons.category,
                iconSize: 36,
                children: (0, _jsxRuntime.jsx)(_.NewspackIcon, {
                  size: 36
                })
              }), (0, _jsxRuntime.jsxs)("div", {
                children: [headerText && (0, _jsxRuntime.jsx)("h2", {
                  children: headerText
                }), subHeaderText && (0, _jsxRuntime.jsx)("span", {
                  children: subHeaderText
                })]
              })]
            })
          })
        }), displayedSections.length > 1 && (0, _jsxRuntime.jsx)(_.TabbedNavigation, {
          items: displayedSections,
          children: (0, _jsxRuntime.jsx)(_WizardError.default, {})
        }), (0, _jsxRuntime.jsx)(_.HandoffMessage, {}), (0, _jsxRuntime.jsxs)(Switch, {
          children: [displayedSections.map((section, index) => {
            const SectionComponent = section.render;
            return (0, _jsxRuntime.jsx)(Route, {
              path: section.path,
              children: (0, _jsxRuntime.jsxs)("div", {
                className: (0, _classnames.default)('newspack-wizard newspack-wizard__content', className),
                children: ['function' === typeof renderAboveSections ? renderAboveSections() : null, (0, _jsxRuntime.jsx)(SectionComponent, {})]
              })
            }, index);
          }), (0, _jsxRuntime.jsx)(Redirect, {
            to: displayedSections[0].path
          })]
        })]
      })
    }), !isLoading && (0, _jsxRuntime.jsx)(_.Footer, {
      simple: hasSimpleFooter
    })]
  });
};
Wizard.useWizardData = _utils.useWizardData;
Wizard.STORE_NAMESPACE = _store.WIZARD_STORE_NAMESPACE;
var _default = Wizard;
exports.default = _default;