import _defineProperty from "@babel/runtime/helpers/defineProperty";
/**
 * Action Card
 */

/**
 * WordPress dependencies
 */
import { Component } from '@wordpress/element';
import { ExternalLink, ToggleControl } from '@wordpress/components';
import { Icon, check, chevronDown, chevronUp } from '@wordpress/icons';

/**
 * Internal dependencies
 */
import { Button, Card, Grid, Handoff, Notice, Waiting } from '../';
import './style.scss';

/**
 * External dependencies
 */
import classnames from 'classnames';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
class ActionCard extends Component {
  constructor() {
    super(...arguments);
    _defineProperty(this, "state", {
      expanded: false
    });
  }
  /**
   * When the collapse prop is updated to true, collapse the card if already expanded.
   */
  componentDidUpdate(prevProps) {
    if (!prevProps.collapse && this.props.collapse && this.state.expanded) {
      this.setState({
        expanded: false
      });
    }
  }

  /**
   * Render.
   */
  render() {
    const {
      badge,
      className,
      checkbox,
      children,
      disabled,
      title,
      description,
      handoff,
      editLink,
      href,
      notification,
      notificationLevel,
      notificationHTML,
      actionContent,
      actionText,
      secondaryActionText,
      secondaryDestructive,
      image,
      imageLink,
      indent,
      isSmall,
      isMedium,
      simple,
      onClick,
      onSecondaryActionClick,
      isWaiting,
      titleLink,
      toggleChecked,
      toggleOnChange,
      hasGreyHeader,
      hasWhiteHeader,
      isPending,
      expandable = false
    } = this.props;
    const {
      expanded
    } = this.state;
    const hasChildren = notification || children;
    const classes = classnames('newspack-action-card', simple && 'newspack-card--is-clickable', hasGreyHeader && 'newspack-card--has-grey-header', hasWhiteHeader && 'newspack-card--has-white-header', hasChildren && 'newspack-card--has-children', indent && 'newspack-card--indent', isSmall && 'is-small', isMedium && 'is-medium', checkbox && 'has-checkbox', expandable && 'is-expandable', actionContent && 'has-action-content', className);
    const backgroundImageStyles = url => {
      return url ? {
        backgroundImage: `url(${url})`
      } : {};
    };
    const titleProps = toggleOnChange && !titleLink && !disabled ? {
      onClick: () => toggleOnChange(!toggleChecked),
      tabIndex: '0'
    } : {};
    const hasInternalLink = href && href.indexOf('http') !== 0;
    const isDisplayingSecondaryAction = secondaryActionText && onSecondaryActionClick;
    const badges = !Array.isArray(badge) && badge ? [badge] : badge;
    return _jsxs(Card, {
      className: classes,
      onClick: simple && onClick,
      children: [_jsxs("div", {
        className: "newspack-action-card__region newspack-action-card__region-top",
        children: [toggleOnChange && _jsx(ToggleControl, {
          checked: toggleChecked,
          onChange: toggleOnChange,
          disabled: disabled
        }), image && !toggleOnChange && _jsx("div", {
          className: "newspack-action-card__region newspack-action-card__region-left",
          children: _jsx("a", {
            href: imageLink,
            children: _jsx("div", {
              className: "newspack-action-card__image",
              style: backgroundImageStyles(image)
            })
          })
        }), checkbox && !toggleOnChange && _jsx("div", {
          className: "newspack-action-card__region newspack-action-card__region-left",
          children: _jsx("span", {
            className: classnames('newspack-checkbox-icon', 'is-primary', 'checked' === checkbox && 'newspack-checkbox-icon--checked', isPending && 'newspack-checkbox-icon--pending'),
            children: 'checked' === checkbox && _jsx(Icon, {
              icon: check
            })
          })
        }), _jsx("div", {
          className: "newspack-action-card__region newspack-action-card__region-center",
          children: _jsxs(Grid, {
            columns: 1,
            gutter: 8,
            noMargin: true,
            children: [_jsxs("h2", {
              children: [_jsxs("span", {
                className: "newspack-action-card__title",
                ...titleProps,
                children: [titleLink && _jsx("a", {
                  href: titleLink,
                  children: title
                }), !titleLink && expandable && _jsx(Button, {
                  isLink: true,
                  onClick: () => this.setState({
                    expanded: !expanded
                  }),
                  children: title
                }), !titleLink && !expandable && title]
              }), badges?.length && badges.map((badgeText, i) => _jsx("span", {
                className: "newspack-action-card__badge",
                children: badgeText
              }, `badge-${i}`))]
            }), description && _jsxs("p", {
              children: [typeof description === 'string' && description, typeof description === 'function' && description()]
            })]
          })
        }), !expandable && (actionText || isDisplayingSecondaryAction || actionContent) && _jsxs("div", {
          className: "newspack-action-card__region newspack-action-card__region-right",
          children: [actionContent && actionContent, actionText && (handoff ? _jsx(Handoff, {
            plugin: handoff,
            editLink: editLink,
            compact: true,
            isLink: true,
            children: actionText
          }) : onClick || hasInternalLink ? _jsx(Button, {
            disabled: disabled,
            isLink: true,
            href: href,
            onClick: onClick,
            className: "newspack-action-card__primary_button",
            children: actionText
          }) : href ? _jsx(ExternalLink, {
            href: href,
            className: "newspack-action-card__primary_button",
            children: actionText
          }) : _jsxs("div", {
            className: "newspack-action-card__container",
            children: [actionText, isWaiting && _jsx(Waiting, {
              isRight: true
            })]
          })), isDisplayingSecondaryAction && _jsx(Button, {
            isLink: true,
            onClick: onSecondaryActionClick,
            className: "newspack-action-card__secondary_button",
            isDestructive: secondaryDestructive,
            children: secondaryActionText
          })]
        }), expandable && _jsx(Button, {
          onClick: () => this.setState({
            expanded: !expanded
          }),
          children: _jsx(Icon, {
            icon: expanded ? chevronUp : chevronDown,
            height: 24,
            width: 24
          })
        })]
      }), notification && _jsxs("div", {
        className: "newspack-action-card__notification newspack-action-card__region-children",
        children: ['error' === notificationLevel && _jsx(Notice, {
          noticeText: notification,
          isError: true,
          rawHTML: notificationHTML
        }), 'info' === notificationLevel && _jsx(Notice, {
          noticeText: notification,
          rawHTML: notificationHTML
        }), 'success' === notificationLevel && _jsx(Notice, {
          noticeText: notification,
          isSuccess: true,
          rawHTML: notificationHTML
        }), 'warning' === notificationLevel && _jsx(Notice, {
          noticeText: notification,
          isWarning: true,
          rawHTML: notificationHTML
        })]
      }), children && (expandable && expanded || !expandable) && _jsx("div", {
        className: "newspack-action-card__region-children",
        children: children
      })]
    });
  }
}
ActionCard.defaultProps = {
  toggleChecked: false
};
export default ActionCard;