/**
 * WordPress dependencies.
 */
import { ColorPicker as ColorPickerComponent } from '@wordpress/components';
import { useState, useRef } from '@wordpress/element';

/**
 * External dependencies.
 */
import classnames from 'classnames';
import { colord, extend } from 'colord';
import a11yPlugin from 'colord/plugins/a11y';

/**
 * Internal dependencies.
 */
import hooks from '../hooks';
import utils from '../utils';
import './style.scss';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
extend([a11yPlugin]);
const {
  InteractiveDiv
} = utils;
const ColorPicker = _ref => {
  let {
    label,
    color = '#fff',
    onChange,
    className
  } = _ref;
  const [isExpanded, setIsExpanded] = useState(false);
  const ref = useRef();
  const colordColor = colord(color);
  hooks.useOnClickOutside(ref, () => setIsExpanded(false));
  return _jsxs("div", {
    className: classnames('newspack-color-picker', className),
    children: [_jsx("div", {
      className: "newspack-color-picker__label",
      children: label
    }), _jsx(InteractiveDiv, {
      className: 'newspack-color-picker__expander',
      onClick: () => setIsExpanded(!isExpanded),
      style: {
        backgroundColor: color,
        color: colordColor.contrast() > colordColor.contrast('#000') ? '#fff' : '#000'
      },
      children: color
    }), _jsx("div", {
      className: "newspack-color-picker__main",
      ref: ref,
      children: isExpanded && _jsx(ColorPickerComponent, {
        color: color,
        onChange: hex => onChange(hex),
        enableAlpha: false
      })
    })]
  });
};
export default ColorPicker;