/**
 * Footer
 */

/**
 * WordPress dependencies.
 */
import { __ as alias__ } from '@wordpress/i18n';
const __ = alias__;
import { ExternalLink } from '@wordpress/components';

/**
 * Internal dependencies.
 */
import { PatronsLogo } from '../';
import './style.scss';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
const Footer = _ref => {
  let {
    simple
  } = _ref;
  const {
    components_demo: componentsDemo = false,
    support = false,
    setup_wizard: setupWizard = false,
    reset_url: resetUrl = false,
    plugin_version: pluginVersion = {
      label: 'Newspack'
    },
    remove_starter_content: removeStarterContent = false,
    support_email: supportEmail
  } = window.newspack_urls || {};
  const footerElements = [{
    label: pluginVersion.label,
    url: 'https://newspack.com/category/release-notes/',
    external: true
  }, {
    label: __('About', 'newspack'),
    url: 'https://newspack.com/',
    external: true
  }, {
    label: __('Documentation', 'newspack'),
    url: support,
    external: true
  }];
  if (componentsDemo) {
    footerElements.push({
      label: __('Components Demo', 'newspack'),
      url: componentsDemo
    });
  }
  if (setupWizard) {
    footerElements.push({
      label: __('Setup Wizard', 'newspack'),
      url: setupWizard
    });
  }
  if (resetUrl) {
    footerElements.push({
      label: __('Reset Newspack', 'newspack'),
      url: resetUrl
    });
  }
  if (removeStarterContent) {
    footerElements.push({
      label: __('Remove Starter Content', 'newspack'),
      url: removeStarterContent
    });
  }
  if (supportEmail) {
    footerElements.push({
      label: __('Contact Support', 'newspack'),
      url: `mailto:${supportEmail}`
    });
  }
  return _jsxs("div", {
    className: "newspack-footer",
    children: [!simple && _jsx("div", {
      className: "newspack-footer__inner",
      children: _jsx("ul", {
        children: footerElements.map((_ref2, index) => {
          let {
            url,
            label,
            external
          } = _ref2;
          return _jsx("li", {
            children: external ? _jsx(ExternalLink, {
              href: url,
              children: label
            }) : _jsx("a", {
              href: url,
              children: label
            })
          }, index);
        })
      })
    }), _jsx("div", {
      className: "newspack-footer__logo",
      children: _jsx(PatronsLogo, {})
    })]
  });
};
export default Footer;