import _defineProperty from "@babel/runtime/helpers/defineProperty";
/**
 * Handoff
 */

/**
 * WordPress dependencies.
 */
import apiFetch from '@wordpress/api-fetch';
import { Component, Fragment } from '@wordpress/element';
import { __ as alias__ } from '@wordpress/i18n';

/**
 * Internal dependencies.
 */
const __ = alias__;
import { Button, Card, Modal, Waiting } from '../';

/**
 * External dependencies.
 */
import assign from 'lodash/assign';
import classnames from 'classnames';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
class Handoff extends Component {
  constructor() {
    super(...arguments);
    _defineProperty(this, "componentDidMount", () => {
      this._isMounted = true;
      const {
        plugin
      } = this.props;
      this.retrievePluginInfo(plugin);
    });
    _defineProperty(this, "componentWillUnmount", () => {
      this._isMounted = false;
    });
    _defineProperty(this, "retrievePluginInfo", plugin => {
      const {
        onReady
      } = this.props;
      apiFetch({
        path: '/newspack/v1/plugins/' + plugin
      }).then(pluginInfo => {
        if (this._isMounted) {
          onReady(pluginInfo);
          this.setState({
            pluginInfo
          });
        }
      });
    });
    _defineProperty(this, "textForPlugin", pluginInfo => {
      const defaults = {
        modalBody: null,
        modalTitle: pluginInfo.Name && `${__('Manage', 'newspack')} ${pluginInfo.Name}`,
        primaryButton: pluginInfo.Name && `${__('Manage', 'newspack')} ${pluginInfo.Name}`,
        primaryModalButton: __('Manage', 'newspack'),
        dismissModalButton: __('Dismiss', 'newspack')
      };
      return assign(defaults, this.props);
    });
    _defineProperty(this, "goToPlugin", plugin => {
      const {
        editLink,
        showOnBlockEditor
      } = this.props;
      apiFetch({
        path: '/newspack/v1/plugins/' + plugin + '/handoff',
        method: 'POST',
        data: {
          editLink,
          handoffReturnUrl: window && window.location.href,
          showOnBlockEditor: showOnBlockEditor ? true : false
        }
      }).then(response => {
        window.location.href = response.HandoffLink;
      });
    });
    this.state = {
      pluginInfo: [],
      showModal: false
    };
  }
  /**
   * Render.
   */
  render() {
    const {
      className,
      children,
      compact,
      useModal,
      // eslint-disable-next-line no-unused-vars,@typescript-eslint/no-unused-vars
      modalTitle: _modalTitle,
      // eslint-disable-next-line no-unused-vars,@typescript-eslint/no-unused-vars
      modalBody: _modalBody,
      // eslint-disable-next-line no-unused-vars,@typescript-eslint/no-unused-vars
      onReady,
      // eslint-disable-next-line no-unused-vars,@typescript-eslint/no-unused-vars
      editLink,
      ...otherProps
    } = this.props;
    const {
      pluginInfo,
      showModal
    } = this.state;
    const {
      modalBody,
      modalTitle,
      primaryButton,
      primaryModalButton,
      dismissModalButton
    } = this.textForPlugin(pluginInfo);
    const {
      Configured,
      Name,
      Slug,
      Status
    } = pluginInfo;
    const classes = classnames(Configured && 'is-configured', className);
    return _jsxs(Fragment, {
      children: [Name && 'active' === Status && _jsx(Button, {
        className: classes,
        isSecondary: !otherProps.isPrimary && !otherProps.isTertiary && !otherProps.isLink,
        ...otherProps,
        onClick: () => useModal ? this.setState({
          showModal: true
        }) : this.goToPlugin(Slug),
        children: children ? children : primaryButton
      }), Name && 'active' !== Status && _jsx(Button, {
        className: classes,
        variant: "secondary",
        disabled: true,
        ...otherProps,
        children: Name + __(' not installed', 'newspack')
      }), !Name && _jsx(Button, {
        className: classes,
        isSecondary: !otherProps.isPrimary && !otherProps.isTertiary && !otherProps.isLink,
        ...otherProps,
        children: _jsxs(Fragment, {
          children: [!compact && _jsx(Waiting, {
            isLeft: true
          }), __('Retrieving Plugin Info', 'newspack')]
        })
      }), showModal && _jsxs(Modal, {
        title: modalTitle,
        onRequestClose: () => this.setState({
          showModal: false
        }),
        children: [_jsx("p", {
          children: modalBody
        }), _jsxs(Card, {
          buttonsCard: true,
          noBorder: true,
          className: "justify-end",
          children: [_jsx(Button, {
            variant: "secondary",
            onClick: () => this.setState({
              showModal: false
            }),
            children: dismissModalButton
          }), _jsx(Button, {
            variant: "primary",
            onClick: () => this.goToPlugin(Slug),
            children: primaryModalButton
          })]
        })]
      })]
    });
  }
}
Handoff.defaultProps = {
  onReady: () => {}
};
export default Handoff;