import React from 'react';
import { render, screen, fireEvent } from '@testing-library/react';
import useObjectState from './useObjectState';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
const INIT_STATE = {
  name: 'Foo',
  widgets: [1],
  attributes: {
    bar: 0,
    baz: 1
  }
};
const TestComponent = () => {
  const [state, updateState] = useObjectState(INIT_STATE);
  return _jsxs("div", {
    children: [_jsx("input", {
      placeholder: "state",
      onChange: () => {},
      value: JSON.stringify(state)
    }), _jsx("button", {
      onClick: () => updateState({
        widgets: []
      }),
      children: "Remove widgets"
    }), _jsx("button", {
      onClick: () => updateState({
        widgets: [1]
      }),
      children: "Add widget"
    }), _jsx("button", {
      onClick: () => updateState({
        attributes: {
          bar: 2
        }
      }),
      children: "Nested update"
    }), _jsx("input", {
      type: "text",
      value: state.name,
      onChange: e => updateState({
        name: e.target.value
      }),
      placeholder: "name"
    })]
  });
};
describe('useObjectState', () => {
  const getState = () => JSON.parse(screen.getByPlaceholderText('state').getAttribute('value'));
  beforeEach(() => {
    render(_jsx(TestComponent, {}));
  });
  it('updates arrays', () => {
    expect(getState()).toStrictEqual(INIT_STATE);
    screen.getByText('Remove widgets').click();
    expect(getState()).toMatchObject({
      widgets: []
    });
    screen.getByText('Add widget').click();
    expect(getState()).toMatchObject({
      widgets: [1]
    });
  });
  it('updates a simple value', () => {
    fireEvent.change(screen.getByPlaceholderText('name'), {
      target: {
        value: 'Ramon'
      }
    });
    expect(getState()).toMatchObject({
      name: 'Ramon'
    });
  });
  it('updates a nested object', () => {
    screen.getByText('Nested update').click();
    expect(getState()).toMatchObject({
      attributes: {
        bar: 2,
        baz: 1
      }
    });
  });
});