import _defineProperty from "@babel/runtime/helpers/defineProperty";
/**
 * Image Upload
 */

/**
 * WordPress dependencies.
 */
import { Component } from '@wordpress/element';
import { __ as alias__ } from '@wordpress/i18n';

/**
 * Internal dependencies.
 */
const __ = alias__;
import { Button, InfoButton } from '../';
import './style.scss';

/**
 * External dependencies.
 */
import classnames from 'classnames';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Fragment as _Fragment } from "@emotion/react/jsx-runtime";
class ImageUpload extends Component {
  /**
   * Constructor.
   */
  constructor() {
    super(...arguments);
    /**
     * Open the WP media modal.
     */
    _defineProperty(this, "openModal", () => {
      if (this.state.frame) {
        this.state.frame.open();
        return;
      }
      this.setState({
        frame: wp.media({
          title: __('Select or upload image'),
          button: {
            text: __('Select')
          },
          library: {
            type: 'image'
          },
          multiple: false
        })
      }, () => {
        this.state.frame.on('select', this.handleImageSelect);
        this.state.frame.open();
      });
    });
    /**
     * Update the state when an image is selected from the media modal.
     */
    _defineProperty(this, "handleImageSelect", () => {
      const {
        onChange
      } = this.props;
      const attachment = this.state.frame.state().get('selection').first().toJSON();
      onChange(attachment);
    });
    /**
     * Render.
     */
    _defineProperty(this, "render", () => {
      const {
        buttonLabel,
        className,
        disabled,
        help,
        image,
        info,
        isCovering,
        label,
        onChange,
        style = {}
      } = this.props;
      const classes = classnames('newspack-image-upload__image', {
        'newspack-image-upload__image--has-image': image
      }, {
        'newspack-image-upload__image--covering': isCovering
      });
      return _jsxs("div", {
        className: classnames('newspack-image-upload', className),
        children: [_jsxs("div", {
          className: "newspack-image-upload__header",
          children: [label && _jsx("label", {
            className: "newspack-image-upload__label",
            children: label
          }), info && _jsx(InfoButton, {
            text: info
          })]
        }), _jsx("div", {
          className: classes,
          style: {
            ...style
          },
          children: image?.url ? _jsxs(_Fragment, {
            children: [_jsx("img", {
              "data-testid": "image-upload",
              src: image.url,
              alt: __('Image preview', 'newspack')
            }), _jsxs("div", {
              className: "newspack-image-upload__controls",
              children: [_jsx(Button, {
                disabled: disabled,
                onClick: this.openModal,
                isLink: true,
                children: __('Replace', 'newspack')
              }), _jsx("span", {
                className: "sep"
              }), _jsx(Button, {
                disabled: disabled,
                onClick: () => onChange(null),
                isLink: true,
                isDestructive: true,
                children: __('Remove', 'newspack')
              })]
            })]
          }) : _jsx(Button, {
            disabled: disabled,
            onClick: this.openModal,
            isLink: true,
            children: buttonLabel ? buttonLabel : __('Upload', 'newspack')
          })
        }), help && _jsx("p", {
          className: "newspack-image-upload__help",
          children: help
        })]
      });
    });
    this.state = {
      frame: false
    };
  }
}
export default ImageUpload;