/**
 * Notice
 */

/**
 * WordPress dependencies.
 */
import { Component, RawHTML } from '@wordpress/element';
import { Icon, bug, check, help, info } from '@wordpress/icons';
import { __ as alias__ } from '@wordpress/i18n';

/**
 * Internal dependencies.
 */
const __ = alias__;
import './style.scss';

/**
 * External dependencies.
 */
import classnames from 'classnames';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
class Notice extends Component {
  /**
   * Render
   */
  render() {
    const {
      className,
      debugMode,
      isError,
      isHandoff,
      isHelp,
      isSuccess,
      isWarning,
      noticeText,
      rawHTML,
      style = {},
      children = null
    } = this.props;
    const classes = classnames('newspack-notice', className, debugMode && 'newspack-notice__is-debug', isError && 'newspack-notice__is-error', isHandoff && 'newspack-notice__is-handoff', isHelp && 'newspack-notice__is-help', isSuccess && 'newspack-notice__is-success', isWarning && 'newspack-notice__is-warning');
    let noticeIcon;
    if (isHelp) {
      noticeIcon = help;
    } else if (isSuccess) {
      noticeIcon = check;
    } else if (debugMode) {
      noticeIcon = bug;
    } else {
      noticeIcon = info;
    }
    return _jsxs("div", {
      className: classes,
      style: style,
      children: [_jsx(Icon, {
        icon: noticeIcon
      }), _jsxs("div", {
        className: "newspack-notice__content",
        children: [rawHTML ? _jsx(RawHTML, {
          children: noticeText
        }) : noticeText, debugMode && __('Debug Mode', 'newspack'), children || null]
      })]
    });
  }
}
export default Notice;