import _defineProperty from "@babel/runtime/helpers/defineProperty";
/**
 * WordPress dependencies.
 */
import apiFetch from '@wordpress/api-fetch';
import { Component, Fragment } from '@wordpress/element';
import { __ as alias__ } from '@wordpress/i18n';

/**
 * Internal dependencies.
 */
const __ = alias__;
import { ActionCard, Waiting } from '../';
import './style.scss';

/**
 * Plugin toggle group component.
 */
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
class PluginToggle extends Component {
  constructor() {
    super(...arguments);
    _defineProperty(this, "state", {
      pluginInfo: {}
    });
    _defineProperty(this, "componentDidMount", () => {
      this.retrievePluginInfo();
    });
    /**
     * Retrieve complete data about Newspack plugins.
     */
    _defineProperty(this, "retrievePluginInfo", () => {
      return new Promise(() => {
        apiFetch({
          path: '/newspack/v1/plugins/'
        }).then(pluginInfo => this.setState({
          pluginInfo
        }));
      });
    });
    /**
     * Install/activate or remove a plugin.
     */
    _defineProperty(this, "managePlugin", (plugin, value) => {
      const {
        plugins
      } = this.props;
      const {
        pluginInfo
      } = this.state;
      const action = value ? 'configure' : 'deactivate';
      const params = {
        path: `/newspack/v1/plugins/${plugin}/${action}/`,
        method: 'post'
      };
      this.setState({
        pluginInfo: {
          ...pluginInfo,
          [plugin]: {
            ...pluginInfo[plugin],
            inFlight: action
          }
        }
      }, () => {
        apiFetch(params).then(response => {
          const {
            shouldRefreshAfterUpdate
          } = plugins[plugin];
          this.setState(_ref => {
            let {
              pluginInfo: currentPluginInfo
            } = _ref;
            return {
              pluginInfo: {
                ...currentPluginInfo,
                [plugin]: response
              }
            };
          }, () => shouldRefreshAfterUpdate && location.reload());
        }).catch(e => {
          this.setState({
            pluginInfo: {
              ...pluginInfo,
              [plugin]: {
                ...pluginInfo[plugin],
                error: e.message || __('There was an error managing this plugin.', 'newspack')
              }
            }
          });
        });
      });
    });
    /**
     * Prepare plugins data for render. Change all keys to camelCase, merge API-fetched data with prop.
     */
    _defineProperty(this, "prepareDataForRender", (pluginsFromProps, pluginsFromAPI) => Object.keys(pluginsFromProps).map(pluginSlug => pluginsFromAPI[pluginSlug] ? Object.keys(pluginsFromAPI[pluginSlug]).reduce((accumulator, key) => ({
      ...accumulator,
      [key.charAt(0).toLowerCase() + key.slice(1)]: pluginsFromAPI[pluginSlug][key]
    }), {}) : {}).map(plugin => Object.assign(plugin, pluginsFromProps[plugin.slug])));
    /**
     * Generate a classname for the ActionCard based on plugin state. Applies 'in-flight' class if an API is underway and 'loading' if the plugin data is not yet available.
     */
    _defineProperty(this, "classNameForPlugin", plugin => {
      const {
        status,
        inFlight
      } = plugin;
      if (inFlight) {
        return 'in-flight';
      }
      if (!status) {
        return 'loading';
      }
    });
    /**
     * Generate the ActionCard action text for a plugin.
     */
    _defineProperty(this, "actionTextForPlugin", plugin => {
      const {
        actionText,
        editPath,
        href,
        inFlight,
        name
      } = plugin;
      // Show spinner when plugin data is unavailable, or when an API call is in flight.
      if ('configure' === inFlight) {
        return _jsxs(Fragment, {
          children: [__('Installing…', 'newspack'), " ", _jsx(Waiting, {
            isRight: true
          })]
        });
      }
      if ('deactivate' === inFlight) {
        return _jsxs(Fragment, {
          children: [__('Deactivating…', 'newspack'), " ", _jsx(Waiting, {
            isRight: true
          })]
        });
      }
      if (!name) {
        return _jsxs(Fragment, {
          children: [__('Loading…', 'newspack'), " ", _jsx(Waiting, {
            isRight: true
          })]
        });
      }
      // No action button at all if the plugin isn't installed and active.
      if (!this.isPluginInstalledAndActive(plugin)) {
        return null;
      }
      if (href || editPath) {
        return actionText ? actionText : __('Configure', 'newspack');
      }
    });
    /**
     * Get error message for this plugin.
     */
    _defineProperty(this, "errorForPlugin", plugin => {
      const {
        slug
      } = plugin;
      const {
        pluginInfo
      } = this.state;
      return pluginInfo[slug]?.error || null;
    });
    /**
     * Get installation/activation status for a plugin.
     */
    _defineProperty(this, "isPluginInstalledAndActive", plugin => {
      const {
        status
      } = plugin;
      return status === 'active';
    });
  }
  /**
   * Render.
   */
  render() {
    const {
      plugins
    } = this.props;
    const {
      pluginInfo
    } = this.state;
    return this.prepareDataForRender(plugins, pluginInfo).map((plugin, index) => {
      const {
        name,
        description,
        href,
        slug,
        editPath
      } = plugin;
      const pluginStatus = this.isPluginInstalledAndActive(plugin);
      const handoff = !href && pluginStatus && editPath ? slug : null;
      const error = this.errorForPlugin(plugin);
      return _jsx(ActionCard, {
        className: this.classNameForPlugin(plugin),
        title: name,
        description: description,
        actionText: this.actionTextForPlugin(plugin),
        handoff: handoff,
        href: href,
        toggle: true,
        toggleChecked: this.isPluginInstalledAndActive(plugin),
        toggleOnChange: value => this.managePlugin(slug, value),
        notification: error,
        notificationHTML: error,
        notificationLevel: "error"
      }, index);
    });
  }
}
export default PluginToggle;