/**
 * WordPress dependencies
 */
import { __ as alias__ } from '@wordpress/i18n';
const __ = alias__;
import { ButtonGroup, Button } from '@wordpress/components';

/**
 * External dependencies
 */
import classnames from 'classnames';

/**
 * Internal dependencies
 */
import './style.scss';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
export default function PositionControl(_ref) {
  let {
    allowedPositions,
    value,
    label,
    help,
    onChange,
    size,
    ...props
  } = _ref;
  /**
   * Set layout options
   */
  const options = size === 'full-width' ? [{
    value: 'top',
    /* translators: Overlay Position */
    label: __('Top', 'newspack')
  }, {
    value: 'center',
    /* translators: Overlay Position */
    label: __('Center', 'newspack')
  }, {
    value: 'bottom',
    /* translators: Overlay Position */
    label: __('Bottom', 'newspack')
  }] : [{
    value: 'top_left',
    /* translators: Overlay Position */
    label: __('Top Left', 'newspack')
  }, {
    value: 'top',
    /* translators: Overlay Position */
    label: __('Top Center', 'newspack')
  }, {
    value: 'top_right',
    /* translators: Overlay Position */
    label: __('Top Right', 'newspack')
  }, {
    value: 'center_left',
    /* translators: Overlay Position */
    label: __('Center Left', 'newspack')
  }, {
    value: 'center',
    /* translators: Overlay Position */
    label: __('Center', 'newspack')
  }, {
    value: 'center_right',
    /* translators: Overlay Position */
    label: __('Center Right', 'newspack')
  }, {
    value: 'bottom_left',
    /* translators: Overlay Position */
    label: __('Bottom Left', 'newspack')
  }, {
    value: 'bottom',
    /* translators: Overlay Position */
    label: __('Bottom Center', 'newspack')
  }, {
    value: 'bottom_right',
    /* translators: Overlay Position */
    label: __('Bottom Right', 'newspack')
  }];
  return _jsxs("div", {
    className: classnames('newspack-position-placement-control', 'size-' + size),
    children: [_jsx("p", {
      className: "components-base-control__label",
      children: label
    }), _jsx(ButtonGroup, {
      "aria-label": __('Select Position', 'newspack'),
      ...props,
      children: options.map((option, index) => {
        return _jsx("div", {
          className: option.value === value ? 'is-selected' : null,
          children: _jsx(Button, {
            isSmall: true,
            title: option.label,
            "aria-label": option.label,
            isPrimary: option.value === value,
            onClick: () => {
              onChange(option.value);
            },
            disabled: allowedPositions?.length && !allowedPositions.includes(option.value)
          })
        }, `newspack-position-placement-item-${index}`);
      })
    }), _jsx("p", {
      className: "components-base-control__help",
      children: help
    })]
  });
}