/**
 * Progress Bar
 */

/**
 * WordPress dependencies.
 */
import { Component } from '@wordpress/element';

/**
 * Internal dependencies.
 */
import './style.scss';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
class ProgressBar extends Component {
  /**
   * Get completion as a percentage.
   *
   * @param {number} completed The number of steps completed.
   * @param {number} total     The total number of steps.
   * @return {number} completion percentage
   */
  getCompletionPercentage(completed, total) {
    if (!total) {
      return 100;
    }
    return Math.max(Math.min(Math.round(completed / total * 100), 100), 0);
  }

  /**
   * Render.
   */
  render() {
    const {
      label,
      completed,
      total,
      displayFraction
    } = this.props;
    const cleanTotal = Math.max(0, parseInt(total) || 0);
    const cleanCompleted = Math.max(0, Math.min(parseInt(completed) || 0, parseInt(cleanTotal)));
    const barStyle = {
      width: this.getCompletionPercentage(cleanCompleted, cleanTotal) + '%'
    };
    return _jsxs("div", {
      className: "newspack-progress-bar",
      children: [(label || displayFraction) && _jsxs("div", {
        className: "newspack-progress-bar__headings",
        children: [label && _jsx("h2", {
          children: label
        }), displayFraction && _jsx("p", {
          className: "is-dark",
          children: _jsxs("strong", {
            children: [cleanCompleted, "/", cleanTotal]
          })
        })]
      }), _jsx("div", {
        className: "newspack-progress-bar__container",
        children: _jsx("div", {
          className: "newspack-progress-bar__bar",
          style: barStyle,
          "data-testid": "progress-bar-indicator"
        })
      })]
    });
  }
}
export default ProgressBar;