/**
 * Section Header
 */

/**
 * WordPress dependencies
 */
import { useEffect, useRef } from '@wordpress/element';

/**
 * Internal dependencies
 */
import { Grid } from '..';
import './style.scss';

/**
 * External dependencies
 */
import classnames from 'classnames';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
const SectionHeader = _ref => {
  let {
    centered = false,
    className = null,
    description,
    heading = 2,
    isWhite = false,
    noMargin = false,
    title,
    id = null
  } = _ref;
  // If id is in the URL as a scrollTo param, scroll to it on render.
  const ref = useRef();
  useEffect(() => {
    const params = new Proxy(new URLSearchParams(window.location.search), {
      get: (searchParams, prop) => searchParams.get(prop)
    });
    const scrollToId = params.scrollTo;
    if (scrollToId && scrollToId === id) {
      // Let parent scroll action run before running this.
      window.setTimeout(() => ref.current.scrollIntoView({
        behavior: 'smooth'
      }), 250);
    }
  }, []);
  const classes = classnames('newspack-section-header', centered && 'newspack-section-header--is-centered', isWhite && 'newspack-section-header--is-white', noMargin && 'newspack-section-header--no-margin', className);
  const HeadingTag = `h${heading}`;
  return _jsx("div", {
    id: id,
    ref: ref,
    children: _jsxs(Grid, {
      columns: 1,
      gutter: 8,
      className: classes,
      children: [typeof title === 'string' && _jsx(HeadingTag, {
        children: title
      }), typeof title === 'function' && _jsx(HeadingTag, {
        children: title()
      }), typeof description === 'string' && _jsx("p", {
        children: description
      }), typeof description === 'function' && _jsx("p", {
        children: description()
      })]
    })
  });
};
export default SectionHeader;