/**
 * External dependencies
 */
import classnames from 'classnames';

/**
 * WordPress dependencies
 */
import { Icon } from '@wordpress/icons';
import { BaseControl, Button, ButtonGroup } from '@wordpress/components';

/**
 * Internal dependencies
 */
import { hooks } from '..';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
const ButtonGroupControl = _ref => {
  let {
    buttonOptions,
    buttonSmall,
    className,
    hideLabelFromVision,
    label,
    onChange,
    value
  } = _ref;
  const id = hooks.useUniqueId('button-group');
  return _jsx(BaseControl, {
    label: label,
    hideLabelFromVision: hideLabelFromVision,
    id: id.current,
    className: classnames(className, 'components-select-control'),
    children: _jsx(ButtonGroup, {
      children: buttonOptions.map(option => {
        const isSelected = value === option.value;
        let Label = () => option.label;
        if (option.icon) {
          // eslint-disable-next-line react/display-name
          Label = () => _jsx(Icon, {
            icon: option.icon
          });
        }
        return _jsx(Button, {
          variant: isSelected ? 'primary' : null,
          isPressed: isSelected,
          onClick: () => onChange(option.value),
          isSmall: buttonSmall,
          children: _jsx(Label, {})
        }, option.value);
      })
    })
  });
};
export default ButtonGroupControl;