/**
 * WordPress dependencies
 */
import { BaseControl } from '@wordpress/components';
import { __ as alias__ } from '@wordpress/i18n';
const __ = alias__;
import { Icon, chevronDown } from '@wordpress/icons';

/**
 * External dependencies
 */
import classnames from 'classnames';
import find from 'lodash/find';
import some from 'lodash/some';

/**
 * Internal dependencies
 */
import { hooks } from '..';

/**
 * SelectControl with optgroup support
 */
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
export default function GroupedSelectControl(_ref) {
  let {
    help,
    label,
    onChange,
    optgroups = [],
    className,
    hideLabelFromVision,
    ...props
  } = _ref;
  const onChangeValue = event => {
    const {
      value
    } = event.target;
    const optgroup = find(optgroups, group => some(group.options, ['value', value]));
    onChange(value, optgroup);
  };
  const id = hooks.useUniqueId('group-select');
  return _jsx(BaseControl, {
    label: label,
    hideLabelFromVision: hideLabelFromVision,
    id: id,
    help: help,
    className: classnames(className, 'components-select-control'),
    children: _jsxs("div", {
      className: "relative",
      children: [_jsxs("select", {
        id: id,
        className: "components-select-control__input",
        onChange: onChangeValue,
        "aria-describedby": !!help ? `${id}__help` : undefined,
        ...props,
        children: [_jsx("option", {
          value: "",
          children: __('-- Select --', 'newspack')
        }), optgroups.map((_ref2, optgroupIndex) => {
          let {
            label: optgroupLabel,
            options
          } = _ref2;
          return _jsx("optgroup", {
            label: optgroupLabel,
            children: options.map((option, optionIndex) => _jsx("option", {
              value: option.value,
              disabled: option.disabled,
              children: option.label
            }, `${option.label}-${option.value}-${optionIndex}`))
          }, optgroupIndex);
        })]
      }), _jsx("div", {
        className: "components-select-control__arrow-wrapper",
        children: _jsx(Icon, {
          icon: chevronDown,
          size: 18
        })
      })]
    })
  });
}