/**
 * External dependencies.
 */
import classnames from 'classnames';
import findIndex from 'lodash/findIndex';
import Router from '../proxied-imports/router';

/**
 * Internal dependencies.
 */
import './style.scss';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
const {
  NavLink,
  useHistory
} = Router;
const TabbedNavigation = _ref => {
  let {
    items,
    className,
    disableUpcoming,
    children = null
  } = _ref;
  const displayedItems = items.filter(item => !item.isHiddenInTabbedNavigation);
  const {
    location
  } = useHistory();
  const currentIndex = findIndex(displayedItems, ['path', location.pathname]);
  return _jsxs("div", {
    className: classnames('newspack-tabbed-navigation', className),
    children: [_jsx("ul", {
      children: displayedItems.map((item, index) => _jsx("li", {
        children: _jsx(NavLink, {
          to: item.path,
          isActive: (match, _ref2) => {
            let {
              pathname
            } = _ref2;
            if (item.activeTabPaths) {
              return item.activeTabPaths.includes(pathname);
            }
            return match;
          },
          exact: true,
          activeClassName: 'selected',
          className: classnames({
            disabled: disableUpcoming && index > currentIndex
          }),
          children: item.label
        })
      }, index))
    }), children]
  });
};
export default TabbedNavigation;