/**
 * Text Control
 */

/**
 * WordPress dependencies
 */
import { TextControl as BaseComponent } from '@wordpress/components';
import { Component, createRef } from '@wordpress/element';
import { __ as alias__ } from '@wordpress/i18n';

/**
 * Internal dependencies
 */
const __ = alias__;
import './style.scss';

/**
 * External dependencies
 */
import classNames from 'classnames';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
class TextControl extends Component {
  constructor(props) {
    super(props);
    this.wrapperRef = createRef();
  }
  componentDidMount() {
    if (this.wrapperRef.current) {
      const labelEl = this.wrapperRef.current.querySelector('label');
      if (labelEl) {
        labelEl.setAttribute('data-required-text', __('(required)', 'newspack'));
      }
    }
  }
  /**
   * Render.
   */
  render() {
    const {
      className,
      required,
      isWide,
      withMargin = true,
      ...otherProps
    } = this.props;
    const classes = classNames('newspack-text-control', {
      'newspack-text-control--wide': isWide
    }, {
      'newspack-text-control--with-margin': withMargin
    }, className);
    return required ? _jsx("div", {
      ref: this.wrapperRef,
      className: "newspack-text-control--required",
      children: _jsx(BaseComponent, {
        className: classes,
        required: required,
        ...otherProps
      })
    }) : _jsx(BaseComponent, {
      className: classes,
      ...otherProps
    });
  }
}
export default TextControl;