import _defineProperty from "@babel/runtime/helpers/defineProperty";
/**
 * WordPress dependencies.
 */
import { Component, createRef, Fragment, createPortal } from '@wordpress/element';
import { __ as alias__ } from '@wordpress/i18n';
const __ = alias__;
import { closeSmall, desktop, mobile, tablet } from '@wordpress/icons';
import { Button, ButtonGroup } from '@wordpress/components';

/**
 * Internal dependencies.
 */
import { Waiting } from '../';
import './style.scss';

/**
 * External dependencies.
 */
import classnames from 'classnames';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
const PORTAL_PARENT_ID = 'newspack-components-web-preview-wrapper';

/**
 * Web Preview. A component to preview a website in an iframe, with device sizing options.
 */
class WebPreview extends Component {
  constructor(props) {
    super(props);
    _defineProperty(this, "state", {
      device: 'desktop',
      loaded: false,
      isPreviewVisible: false
    });
    /**
     * Create JSX for the modal
     */
    _defineProperty(this, "getWebPreviewModal", () => {
      const {
        beforeLoad = () => {},
        onClose = () => {},
        url
      } = this.props;
      const {
        device,
        loaded,
        isPreviewVisible
      } = this.state;
      if (!this.modalDOMElement || !isPreviewVisible) {
        return null;
      }
      const classes = classnames('newspack-web-preview', device, loaded && 'is-loaded');
      beforeLoad();
      return createPortal(_jsx("div", {
        className: classes,
        children: _jsxs("div", {
          className: "newspack-web-preview__interior",
          children: [_jsxs("div", {
            className: "newspack-web-preview__toolbar",
            children: [_jsx("div", {
              className: "newspack-web-preview__toolbar-left",
              children: _jsxs(ButtonGroup, {
                children: [_jsx(Button, {
                  onClick: () => this.setState({
                    device: 'desktop'
                  }),
                  variant: 'desktop' === device && 'primary',
                  icon: desktop,
                  label: __('Preview Desktop Size', 'newspack')
                }), _jsx(Button, {
                  onClick: () => this.setState({
                    device: 'tablet'
                  }),
                  variant: 'tablet' === device && 'primary',
                  icon: tablet,
                  label: __('Preview Tablet Size', 'newspack')
                }), _jsx(Button, {
                  onClick: () => this.setState({
                    device: 'phone'
                  }),
                  variant: 'phone' === device && 'primary',
                  icon: mobile,
                  label: __('Preview Phone Size', 'newspack')
                })]
              })
            }), _jsx("div", {
              className: "newspack-web-preview__toolbar-right",
              children: _jsx(Button, {
                onClick: () => {
                  onClose();
                  this.setState({
                    isPreviewVisible: false,
                    loaded: false
                  });
                },
                icon: closeSmall,
                label: __('Close Preview', 'newspack')
              })
            })]
          }), _jsxs("div", {
            className: "newspack-web-preview__content",
            children: [!loaded && _jsxs("div", {
              className: "newspack-web-preview__is-waiting",
              children: [_jsx(Waiting, {
                isLeft: true
              }), __('Loading…', 'newspack')]
            }), _jsx("iframe", {
              ref: this.iframeRef,
              title: "web-preview",
              src: url,
              onLoad: () => {
                this.setState({
                  loaded: true
                });
                this.props.onLoad(this.iframeRef.current);
              }
            })]
          })]
        })
      }), this.modalDOMElement);
    });
    _defineProperty(this, "showPreview", () => {
      this.setState({
        isPreviewVisible: true
      });
    });
    this.iframeRef = createRef();
  }

  /**
   * If a div with id PORTAL_PARENT_ID exists, assign it to class field.
   * If not, create it and append to the body.
   */
  componentDidMount() {
    const existingDOMElement = document.getElementById(PORTAL_PARENT_ID);
    this.modalDOMElement = existingDOMElement || document.createElement('div');
    if (!existingDOMElement) {
      this.modalDOMElement.id = PORTAL_PARENT_ID;
      document.body.appendChild(this.modalDOMElement);
    }
  }

  /**
   * Add or remove applicable body classes
   */
  componentDidUpdate() {
    if (this.state.isPreviewVisible === true) {
      document.body.classList.add('newspack-web-preview--open');
    } else {
      document.body.classList.remove('newspack-web-preview--open');
    }
  }
  /**
   * Render.
   */
  render() {
    const {
      label,
      variant,
      /**
       * Inversion of control - let the caller render
       * the button that will trigger the modal
       */
      renderButton
    } = this.props;
    return _jsxs(Fragment, {
      children: [renderButton ? renderButton({
        showPreview: this.showPreview
      }) : _jsx(Button, {
        variant: variant,
        onClick: this.showPreview,
        tabIndex: "0",
        children: label
      }), this.getWebPreviewModal()]
    });
  }
}
WebPreview.defaultProps = {
  url: '//newspack.com',
  label: __('Preview', 'newspack'),
  onLoad: () => {}
};
export default WebPreview;