/**
 * WordPress dependencies.
 */
import { __ as alias__ } from '@wordpress/i18n';
const __ = alias__;
import { category } from '@wordpress/icons';

/**
 * Internal dependencies
 */
import { Button, Handoff, NewspackIcon, Notice, HandoffMessage, TabbedNavigation } from '../';
import { buttonProps } from '../../../shared/js/';
import './style.scss';

/**
 * External dependencies
 */
import classnames from 'classnames';

/**
 * Higher-Order Component to provide plugin management and error handling to Newspack Wizards.
 */
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Fragment as _Fragment } from "@emotion/react/jsx-runtime";
export default function withWizardScreen(WrappedComponent) {
  let {
    hidePrimaryButton
  } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  const WrappedWithWizardScreen = props => {
    const {
      className,
      buttonText,
      buttonAction,
      buttonDisabled,
      headerText,
      subHeaderText,
      tabbedNavigation,
      secondaryButtonText,
      secondaryButtonAction,
      renderAboveContent,
      disableUpcomingInTabbedNavigation
    } = props;
    const retrievedButtonProps = buttonProps(buttonAction);
    const retrievedSecondaryButtonProps = buttonProps(secondaryButtonAction);
    const SecondaryCTAComponent = retrievedSecondaryButtonProps.plugin ? Handoff : Button;
    const shouldRenderPrimaryButton = buttonText && buttonAction;
    const shouldRenderSecondaryButton = secondaryButtonText && secondaryButtonAction;
    const renderPrimaryButton = function () {
      let overridingProps = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return retrievedButtonProps.plugin ? _jsx(Handoff, {
        isPrimary: true,
        ...retrievedButtonProps,
        ...overridingProps,
        children: buttonText
      }) : _jsx(Button, {
        isPrimary: !buttonDisabled,
        isSecondary: !!buttonDisabled,
        disabled: buttonDisabled
        // Allow overridingProps to set children.
        // eslint-disable-next-line react/no-children-prop
        ,
        children: buttonText,
        ...retrievedButtonProps,
        ...overridingProps
      });
    };
    return _jsxs(_Fragment, {
      children: [newspack_aux_data.is_debug_mode && _jsx(Notice, {
        debugMode: true
      }), _jsx("div", {
        className: "newspack-wizard__header",
        children: _jsx("div", {
          className: "newspack-wizard__header__inner",
          children: _jsxs("div", {
            className: "newspack-wizard__title",
            children: [_jsx(Button, {
              isLink: true,
              href: newspack_urls.dashboard,
              label: __('Return to Dashboard', 'newspack'),
              showTooltip: true,
              icon: category,
              iconSize: 36,
              children: _jsx(NewspackIcon, {
                size: 36
              })
            }), _jsxs("div", {
              children: [headerText && _jsx("h2", {
                children: headerText
              }), subHeaderText && _jsx("span", {
                children: subHeaderText
              })]
            })]
          })
        })
      }), tabbedNavigation && _jsx(TabbedNavigation, {
        disableUpcoming: disableUpcomingInTabbedNavigation,
        items: tabbedNavigation.filter(item => !item.isHiddenInNav)
      }), _jsx(HandoffMessage, {}), _jsxs("div", {
        className: classnames('newspack-wizard newspack-wizard__content', className),
        children: [typeof renderAboveContent === 'function' ? renderAboveContent() : null, _jsx(WrappedComponent, {
          ...props,
          renderPrimaryButton: renderPrimaryButton
        }), (shouldRenderPrimaryButton || shouldRenderSecondaryButton) && _jsxs("div", {
          className: "newspack-buttons-card",
          children: [shouldRenderPrimaryButton && !hidePrimaryButton && renderPrimaryButton(), shouldRenderSecondaryButton && _jsx(SecondaryCTAComponent, {
            isSecondary: true,
            ...retrievedSecondaryButtonProps,
            children: secondaryButtonText
          })]
        })]
      })]
    });
  };
  return WrappedWithWizardScreen;
}