/**
 * WordPress dependencies.
 */
import { __ as alias__ } from '@wordpress/i18n';
const __ = alias__;
import { useSelect } from '@wordpress/data';

/**
 * Internal dependencies.
 */
import { Button, Card, Modal, Notice } from '../..';
import { WIZARD_STORE_NAMESPACE } from '../store';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
const parseError = _ref => {
  let {
    data,
    message,
    code
  } = _ref;
  let level = 'fatal';
  if (!!data && 'level' in data) {
    level = data.level;
  } else if ('rest_invalid_param' === code) {
    level = 'notice';
  }
  return {
    message,
    level
  };
};
const WizardError = () => {
  const error = useSelect(select => select(WIZARD_STORE_NAMESPACE).getError());
  if (!error) {
    return null;
  }
  const {
    level,
    message
  } = parseError(error);
  if ('fatal' === level) {
    const fallbackURL = typeof newspack_urls !== 'undefined' && newspack_urls.dashboard;
    return _jsxs(Modal, {
      title: __('Unrecoverable error'),
      onRequestClose: fallbackURL ? () => window.location = fallbackURL : undefined,
      children: [_jsx(Notice, {
        noticeText: message,
        isError: true,
        rawHTML: true
      }), fallbackURL && _jsx(Card, {
        buttonsCard: true,
        noBorder: true,
        className: "justify-end",
        children: _jsx(Button, {
          isPrimary: true,
          href: fallbackURL,
          children: __('Return to Dashboard', 'newspack')
        })
      })]
    });
  }
  return _jsx(Notice, {
    isError: true,
    className: "newspack-wizard__above-header",
    noticeText: message,
    rawHTML: true
  });
};
export default WizardError;