/**
 * External dependencies.
 */
import classnames from 'classnames';

/**
 * WordPress dependencies.
 */
import { useSelect } from '@wordpress/data';
import { useState } from '@wordpress/element';
import { __ as alias__ } from '@wordpress/i18n';
const __ = alias__;
import { category } from '@wordpress/icons';

/**
 * Internal dependencies
 */
import { Footer, Notice, Button, NewspackIcon, TabbedNavigation, PluginInstaller, HandoffMessage } from '../';
import Router from '../proxied-imports/router';
import registerStore, { WIZARD_STORE_NAMESPACE } from './store';
import { useWizardData } from './store/utils';
import WizardError from './components/WizardError';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Fragment as _Fragment } from "@emotion/react/jsx-runtime";
registerStore();
const {
  HashRouter,
  Redirect,
  Route,
  Switch
} = Router;
const Wizard = _ref => {
  let {
    sections = [],
    apiSlug,
    headerText,
    subHeaderText,
    hasSimpleFooter,
    className,
    renderAboveSections,
    requiredPlugins = []
  } = _ref;
  const isLoading = useSelect(select => select(WIZARD_STORE_NAMESPACE).isLoading());
  const isQuietLoading = useSelect(select => select(WIZARD_STORE_NAMESPACE).isQuietLoading());

  // Trigger initial data fetch. Some sections might not use the wizard data,
  // but for consistency, fetching is triggered regardless of the section.
  useSelect(select => select(WIZARD_STORE_NAMESPACE).getWizardAPIData(apiSlug));
  let displayedSections = sections.filter(section => !section.isHidden);
  const [pluginRequirementsSatisfied, setPluginRequirementsSatisfied] = useState(requiredPlugins.length === 0);
  if (!pluginRequirementsSatisfied) {
    headerText = requiredPlugins.length > 1 ? __('Required plugins', 'newspack') : __('Required plugin', 'newspack');
    displayedSections = [{
      path: '/',
      render: () => _jsx(PluginInstaller, {
        plugins: requiredPlugins,
        onStatus: _ref2 => {
          let {
            complete
          } = _ref2;
          return setPluginRequirementsSatisfied(complete);
        }
      })
    }];
  }
  return _jsxs(_Fragment, {
    children: [_jsx("div", {
      className: classnames(isLoading ? 'newspack-wizard__is-loading' : 'newspack-wizard__is-loaded', {
        'newspack-wizard__is-loading-quiet': isQuietLoading
      }),
      children: _jsxs(HashRouter, {
        hashType: "slash",
        children: [newspack_aux_data.is_debug_mode && _jsx(Notice, {
          debugMode: true
        }), _jsx("div", {
          className: "bg-white",
          children: _jsx("div", {
            className: "newspack-wizard__header__inner",
            children: _jsxs("div", {
              className: "newspack-wizard__title",
              children: [_jsx(Button, {
                isLink: true,
                href: newspack_urls.dashboard,
                label: __('Return to Dashboard', 'newspack'),
                showTooltip: true,
                icon: category,
                iconSize: 36,
                children: _jsx(NewspackIcon, {
                  size: 36
                })
              }), _jsxs("div", {
                children: [headerText && _jsx("h2", {
                  children: headerText
                }), subHeaderText && _jsx("span", {
                  children: subHeaderText
                })]
              })]
            })
          })
        }), displayedSections.length > 1 && _jsx(TabbedNavigation, {
          items: displayedSections,
          children: _jsx(WizardError, {})
        }), _jsx(HandoffMessage, {}), _jsxs(Switch, {
          children: [displayedSections.map((section, index) => {
            const SectionComponent = section.render;
            return _jsx(Route, {
              path: section.path,
              children: _jsxs("div", {
                className: classnames('newspack-wizard newspack-wizard__content', className),
                children: ['function' === typeof renderAboveSections ? renderAboveSections() : null, _jsx(SectionComponent, {})]
              })
            }, index);
          }), _jsx(Redirect, {
            to: displayedSections[0].path
          })]
        })]
      })
    }), !isLoading && _jsx(Footer, {
      simple: hasSimpleFooter
    })]
  });
};
Wizard.useWizardData = useWizardData;
Wizard.STORE_NAMESPACE = WIZARD_STORE_NAMESPACE;
export default Wizard;